#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeExtremumPolar(HybridShape):

    """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeExtremumPolar
                | 
                | Represents the hybrid shape extremum polar feature.
                | Role: To access the data of the extremum polar feature . This data
                | includes:
                | 
                |     The contour
                |     The support (if exist )
                |     The direction of evaluation
                |     The extermum type
                | 
                | Use the HybridShapeFactory.AddNewExtremumPolarto create a
                | HybridShapeExtremumPolar object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_extremum_polar = com_object

    @property
    def angle(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Angle() As Angle (Read Only)
                | 
                |     returns the resulting angle of extremum.

        :return: Angle
        """

        return Angle(self.hybrid_shape_extremum_polar.Angle)

    @property
    def contour(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Contour() As Reference
                | 
                |     returns or sets the input contour.

        :return: Reference
        """

        return Reference(self.hybrid_shape_extremum_polar.Contour)

    @contour.setter
    def contour(self, value):
        """
        :param Reference value:
        """

        self.hybrid_shape_extremum_polar.Contour = value

    @property
    def dir(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Dir() As HybridShapeDirection
                | 
                |     returns or sets the direction of computation.

        :return: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_extremum_polar.Dir)

    @dir.setter
    def dir(self, value):
        """
        :param HybridShapeDirection value:
        """

        self.hybrid_shape_extremum_polar.Dir = value

    @property
    def extremum_type(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ExtremumType() As short
                | 
                |     returns or sets the type of extremum.

        :return: enum
        """

        return self.hybrid_shape_extremum_polar.ExtremumType

    @extremum_type.setter
    def extremum_type(self, value):
        """
        :param enum value:
        """

        self.hybrid_shape_extremum_polar.ExtremumType = value

    @property
    def origin(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Origin() As Reference
                | 
                |     returns or sets the origin of the polar axis.

        :return: Reference
        """

        return Reference(self.hybrid_shape_extremum_polar.Origin)

    @origin.setter
    def origin(self, value):
        """
        :param Reference value:
        """

        self.hybrid_shape_extremum_polar.Origin = value

    @property
    def radius(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Radius() As Length (Read Only)
                | 
                |     returns the resulting radius of extremum.

        :return: Length
        """

        return Length(self.hybrid_shape_extremum_polar.Radius)

    @property
    def support(self):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Support() As Reference
                | 
                |     returns or sets the support (if exist).

        :return: Reference
        """

        return Reference(self.hybrid_shape_extremum_polar.Support)

    @support.setter
    def support(self, value):
        """
        :param Reference value:
        """

        self.hybrid_shape_extremum_polar.Support = value

    def __repr__(self):
        return f'HybridShapeExtremumPolar(name="{ self.name }")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.any_object import AnyObject
from .hybrid_bodies import HybridBodies
from .hybrid_shapes import HybridShapes
from .ordered_geometrical_sets import OrderedGeometricalSets
from .shapes import Shapes
from .sketches import Sketches


class Body(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | The object that manages a sequence of shapes, a set of sketches, a set
                | of hybrid bodies, a set of ordered geometrical sets and a set of
                | hybrid shapes.It belongs to
                | theactivateLinkAnchor('Bodies','','Bodies')collection of aactivateLink
                | Anchor('Part','','Part')oractivateLinkAnchor('HybridBody','','HybridBo
                | dy')object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.body = com_object
        self.com_object = com_object

    @property
    def hybrid_bodies(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | HybridBodies
                | o Property HybridBodies() As HybridBodies
                | 
                | Returns the body's HybridBodies collection.  Example:The following
                | example returns in hybridBodyColl the collection of hybrid bodies of
                | the main body of partDoc part document:  Dim body As Body Set body =
                | partDoc.Part.Bodies.MainBody Set hybridBodyColl = body.HybridBodies

        """
        return HybridBodies(self.body.HybridBodies)

    @property
    def hybrid_shapes(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | HybridShapes
                | o Property HybridShapes() As HybridShapes
                | 
                | Returns the list of hybrid shapes included in the body.  Returns:
                | oHybridShapes   The list of hybrid shapes in the body (@see
                | CATIAHybridShapes   for more information).
                | Example:
                | The following example returns in HybridShapes1 the list of hybrid
                | shapes in the body Body1:
                | Dim HybridShapes1 As HybridShapes
                | Set HybridShapes1 = Body1.HybridShapes

        :return: HybridShapes()
        """
        return HybridShapes(self.body.HybridShapes)

    @property
    def in_boolean_operation(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | InBooleanOperation
                | o Property InBooleanOperation() As boolean
                | 
                | Returns True if the body is involved in a boolean operation, else
                | returns False.
                | Example:
                | The following example returns in operated True
                | if the body body1belongs to a  boolean operation.
                | operated = body1.InBooleanOperation

        :return: bool
        """
        return self.body.InBooleanOperation

    @property
    def ordered_geometrical_sets(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | OrderedGeometricalSets
                | o Property OrderedGeometricalSets() As OrderedGeometricalSets
                | 
                | Returns the body's OrderedGeometricalSets collection.
                | ometricalSetColl = Body1.OrderedGeometricalSets
                |
                | Example:
                | The following example returns in OrderedGeometricalSetColl the collection
                | of ordered geometrical set of the body Body1 :
                | Set OrderedGe

        """
        return OrderedGeometricalSets(self.body.OrderedGeometricalSets)

    @property
    def shapes(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Shapes
                | o Property Shapes() As Shapes
                | 
                | Returns the body's Shapes collection. These shapes make up the
                | sequence of shapes that will produce an intermediate result for the
                | part, or the final result in the case of the main body.
                |
                | Example:
                | The following example returns in shapColl the collection of shapes managed
                | by the main body of the partDoc part document:
                | Dim body As Body
                | Set body = partDoc.Part.Bodies.MainBody
                | Set shapColl = body.Shapes


        """
        return Shapes(self.body.Shapes)

    @property
    def sketches(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Sketches
                | o Property Sketches() As Sketches
                | 
                | Returns the body's Sketches collection. These sketches are those
                | inside the body at all levels.
                |
                | Example:
                | The following example returns in skColl the collection of sketches of the main body of partDoc part
                | document:
                | Dim body As Body
                | Set body = partDoc.Part.Bodies.MainBody
                | Set skColl = body.Sketches

        """
        return Sketches(self.body.Sketches)

    def insert_hybrid_shape(self, i_hybrid_shape):
        """
        .. note::
            CAA V5 Visual Basic help

                | InsertHybridShape
                | o Sub InsertHybridShape(    HybridShape    iHybridShape)
                | 
                | Insert a hybrid shape to the body.
                |
                | Parameters:
                | iHybriShape
                |   The hybrid shape to insert.
                |
                | Examples:
                | 
                | This example inserts the hybrid shape HybridShape1
                | to the body Body1:
                | 
                | Body1.InsertHybridShape (HybridShape1)

        """
        self.body.InsertHybridShape(i_hybrid_shape)

    def __repr__(self):
        return f'Body(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25

from pywintypes import com_error

from pathlib import Path

from pycatia.exception_handling.exceptions import CATIAApplicationException
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.in_interfaces.document import Document
from pycatia.in_interfaces.documents import Documents


class Application(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Application
                |
                | Represents the current CNext application and its frame window.
                | The application is the root object for all the other objects you can use and
                | access from scripts. It directly aggregates:
                |
                |     The document collection represented by the Documents object. This
                |     collection contains all the documents currently opened by the
                |     application
                |     The window collection represented by the Windows object. This collection
                |     contains all the windows currently opened by the application, each window
                |     displaying one of the documents contained in the document
                |     collection
                |     The SystemService object, providing information about the system
                |     environment.
                |
                | The active document and the active window are two key objects for the
                | application you can access using the ActiveDocument and ActiveWindow properties
                | respectively. The active window is the window the end user is currently working
                | in, and the active document is the document displayed in this active window and
                | that the end user is being editing. This document sets its workshop, that is
                | the available menus and toolbars that make it possible to edit it, according to
                | its type.
                |
                | When you create or use macros for in-process access, the application is always
                | referred to as CATIA.

    """

    def __init__(self, com_object):
        super().__init__(com_object)

    @property
    def active_document(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | ActiveDocument
                | o Property ActiveDocument() As   (Read Only)
                | 
                | Returns the active document. The active document is the document the
                | end user is being editing.
                | Example:
                | This example retrieves in ActiveDoc the active document of the CATIA application.
                | Dim ActiveDoc As Document
                | Set ActiveDoc = CATIA.ActiveDocument

        :return: Document()
        """
        try:
            return Document(self.application.ActiveDocument)
        except com_error:
            raise CATIAApplicationException('Is there an active document?')

    @property
    def active_printer(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | ActivePrinter
                | o Property ActivePrinter() As Printer
                | 
                | Returns or sets the active printer. The active printer is the printer
                | on which documents are printed
                | Example:
                | This example retrieves in ActivePrinter the active printer of the CATIA application.
                | Dim ActivePrinter As Printer
                | Set ActivePrinter = CATIA.ActivePrinter

        :return:
        """
        return self.application.ActivePrinter

    @property
    def active_window(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | ActiveWindow
                | o Property ActiveWindow() As Window   (Read Only)
                | 
                | Returns the active window. The active window is the window in which
                | the end user is currently editing the active document.
                |
                | Example:
                | This example retrieves in ActiveWin the active window of the CATIA
                | application.
                | Dim ActiveWin As Window
                | Set ActiveWin = CATIA.ActiveWindow

        :return:
        """
        return self.application.ActiveWindow

    @property
    def cache_size(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | CacheSize
                | o Property CacheSize() As
                | 
                | Returns or sets the default local cache size used by the application.
                |
                | Example:
                | This example sets the cache size for by the CATIA application
                | to those defined in LocalCacheSize.
                | LocalCacheSize = 10
                | CATIA.CacheSize = LocalCacheSize

        :return:
        """
        return self.application.CacheSize

    @property
    def caption(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Caption
                | o Property Caption() As
                | 
                | Returns or sets the application's window title. This title is
                | displayed in the application's window title bar.
                |
                | Example:
                | This example retrieves in Title the CATIA application's window title.
                | Title = CATIA.Caption
                | The returned value is like this:
                | CNext

        :return: str
        """
        return self.application.Caption

    @property
    def display_file_alerts(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | DisplayFileAlerts
                | o Property DisplayFileAlerts() As
                | 
                | Returns or sets the application ability to display file alerts. True
                | if the application enables file alert display.  True is the default. A
                | file alert is, for example, the dialog box that prompts you that the
                | file you want to save is in read only mode, or that the file you want
                | to close needs to be saved. It could be handy to disable these file
                | alerts for automation since they may freeze your macro execution,
                | waiting for an end user input in the  displayed dialog box.
                |
                | Example:
                | This example disables file alerts for the CATIA application.
                | CATIA.DisplayFileAlerts = False

        :return: bool
        """
        return self.application.DisplayFileAlerts

    @property
    def documents(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Documents
                | o Property Documents() As   (Read Only)
                | 
                | Returns the collection of documents currently managed by the
                | application.
                |
                | Example:
                | This example retrieves in DocCollection the collection of documents
                | currently managed by the CATIA application.
                | Dim DocCollection As Documents
                | Set DocCollection = CATIA.Documents

        :return: Documents()
        """
        return Documents(self.application.Documents)

    @property
    def file_search_order(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | FileSearchOrder
                | o Property FileSearchOrder() As CATBSTR
                | 
                | Returns or sets the default path concatenation. Role: This property
                | returns or sets the default path concatenation used by Other folders
                | setting of the Linked Documents Localization function.      The
                | primary aim of the Linked Documents Localization function is to
                | resolve document links and to manage the strategy that will be used to
                | locate your linked documents.
                |
                | Example:
                | This example sets the paths to
                | search for by the CATIA application to those defined in
                | PathConcatenation.
                | PathConcatenation = "/u/users/fbq/db/model:/u/users/psr/db/model"
                | CATIA.FileSearchOrder = PathConcatenation
                |
                | These methods require the installation of CATIA -
                | PPR xPDM Gateway 1 Product (PX1) In case this product is not granted,
                | the first invocation to one of the methods will fail.

        :return: str
        """
        return self.application.FileSearchOrder

    @property
    def file_system(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | FileSystem
                | o Property FileSystem() As FileSystem  (Read Only)
                | 
                | Returns the file system. The file system provides access to a
                | computer's file system.
                |
                | Example: This example retrieves in AppliFileSys the file system of the CATIA application.
                | Dim AppliFileSys As FileSystem
                | Set AppliFileSys = CATIA.FileSystem

        :return:
        """
        return self.application.FileSystem

    @property
    def full_name(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | FullName
                | o Property FullName() As   (Read Only)
                | 
                | Returns the application's executable file full name, including its
                | path. This name is the name of the executable file used to start the
                | application.
                |
                | Example: This example retrieves in ApplicationFullName
                | the CATIA application's executable file full name.
                | ApplicationFullName = CATIA.FullName
                | The returned value is like this:
                | //lisa//cxr1arel//bsf//alpha_a//code//bin//CNEXT.exe


        :return: str
        """
        return self.application.FullName

    @property
    def hso_synchronized(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | HSOSynchronized
                | o Property HSOSynchronized() As
                | 
                | For selection performance purposes, returns or sets the HSO
                | synchronization in comparison with the CSO. Role: Precises if, for all
                | object instances, the HSO (Highlighted Set of Objects) is synchronized
                | in comparison with the CSO (Current Set of Objects). Valid values
                | are:True: In this case, Selection methods work directly with CATIA's
                | CSO, to reflect instantly the changes made in Automation Selection.
                | This ensures correct selection results, but may impact performance in
                | certain cases. This is the default value at the beginning of a CATIA
                | session. False: In this case, Selection methods work with an internal
                | SO buffer, which allows faster execution when performing a large
                | number of CSO-independent Selection calls, or when performing a single
                | Selection call working on a large number of objects (usually the
                | Search method). This may also prevent the features from blinking
                | between two user interactions.Note: even if this property is set to
                | False, the HSO is synchronized in comparison with the CSO at the
                | beginning of the following methods: Selection.SelectElement2Selection.S
                | electElement3Selection.SelectElement4Selection.IndicateOrSelectElement
                | 2DSelection.IndicateOrSelectElement3DApplication.StartCommandCAUTION:
                | If you use the False value of this property, you must make sure to
                | reset it to True for CATIA's CSO to reflect properly the changes made
                | in Automation Selection. For example, it should be reset to True
                | before interactive parts of your script: MsgBox, InputBox calls, VBA
                | forms updates and so on.

        :return:
        """
        return self.application.HSOSynchronized

    @property
    def height(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Height
                | o Property Height() As
                | 
                | Returns or sets the height of the application's frame window. The
                | height is expressed in pixels.
                |
                | Example: This example sets the height of the CATIA application's frame window to 300 pixels.
                | CATIA.Height = 300

        :return:
        """
        return self.application.Height

    @height.setter
    def height(self, value):
        self.application.Height = value

    @property
    def interactive(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Interactive
                | o Property Interactive() As
                | 
                | Returns or sets the application sensitivity to end user interactions.
                | True if the application is end user interaction sensitive.  Example:
                | This example makes the CATIA application sensitive to end user
                | interactions.  CATIA.Interactive = True

        :return: bool
        """
        return self.application.Interactive

    @interactive.setter
    def interactive(self, value):
        self.application.Interactive = value

    @property
    def left(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Left
                | o Property Left() As
                | 
                | Returns or sets the distance from the application's frame window left
                | side to the left side of the screen. This distance is expressed in
                | pixels.
                |
                | Example:
                | This example sets the distance from the CATIA application's frame window
                | left side to the left side of the screen to 150 pixels.
                | CATIA.Left = 150

        :return: float
        """
        return self.application.Left

    @left.setter
    def left(self, value):
        self.application.Left = value

    @property
    def local_cache(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | LocalCache
                | o Property LocalCache() As
                | 
                | Returns or sets the default local cache path used by the application.
                | Example: This example sets the cache path for by the CATIA application
                | to those defined in LocalCachePath.  LocalCachePath= "/tmp/cache"
                | CATIA.LocalCache = LocalCachePath

        :return: str
        """
        return self.application.LocalCache

    @local_cache.setter
    def local_cache(self, value):
        self.application.LocalCache = value

    @property
    def path(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Path
                | o Property Path() As   (Read Only)
                | 
                | Returns the path of the application's executable files.
                |
                | Example: This example retrieves in ApplicationPath the path where the CATIA
                | application executable files are located.
                | ApplicationPath = CATIA.Path
                | The returned value is like this:
                | //lisa//cxr1arel//bsf//alpha_a//code//bin

        :return: Path()
        """
        return Path(self.application.Path)

    @property
    def printers(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Printers
                | o Property Printers() As   (Read Only)
                | 
                | Returns the collection of the printers currently managed by the
                | application.
                |
                | Example:
                | This example retrieves in PrintersCollection the
                | collection of the printers currently managed by the CATIA application.
                | Dim PrintersCollection As Windows
                | Set PrintersCollection = CATIA.Printers

        :return:
        """
        return self.application.Printers

    @property
    def refresh_display(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | RefreshDisplay
                | o Property RefreshDisplay() As
                | 
                | Enables or disables the update of the display during the script
                | replay. To improve performance, this update can be temporarily
                | disabled by setting  this property to False in the script. True (value
                | set by default) if the application's display is refreshed after each
                | method call  executed in late binding mode . This property does not
                | affect early binding calls nor the get methods because they are never
                | followed  by a refresh of the display.
                |
                | Example: This example makes the update of the CATIA application's display
                | disabled during the script replay.
                | CATIA.RefreshDisplay = False

        :return: bool
        """
        return self.application.RefreshDisplay

    @refresh_display.setter
    def refresh_display(self, value):
        self.application.RefreshDisplay = value

    @property
    def status_bar(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | StatusBar
                | o Property StatusBar() As
                | 
                | Returns or sets the text displayed in the application's window status
                | bar.
                |
                | Example: This example retrieves in Text the text displayed in
                | the CATIA application's window status bar.
                | Text = CATIA.StatusBar
                | The returned value is like this:
                | Welcome to CATIA CxR1

        :return: str
        """
        return self.application.StatusBar

    @status_bar.setter
    def status_bar(self, value):
        self.application.StatusBar = value

    @property
    def system_configuration(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | SystemConfiguration
                | o Property SystemConfiguration() As   (Read Only)
                | 
                | Returns the system configuration object (an object which provides
                | access to system or configuration dependent resources).
                |
                | Parameters:
                | oConfiguration
                |  The system configuration object.

        :return:
        """
        return self.application.SystemConfiguration

    @property
    def system_service(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | SystemService
                | o Property SystemService() As   (Read Only)
                | 
                | Returns system services. Example: This example retrieves in
                | AppliSysSer the CATIA application's system services.  Dim AppliSysSer
                | As SystemService Set AppliSysSer = CATIA.SystemService

        :return:
        """
        return self.application.SystemService

    @property
    def top(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Top
                | o Property Top() As
                | 
                | Returns or sets the distance from the application'si frame window top
                | to the top of the screen. This distance is expressed in pixels.
                |
                | Example:
                | This example sets the distance from the CATIA  application's
                | frame window top to the top of the screen to 50 pixels.
                | CATIA.Top = 50

        :return: float
        """
        return self.application.Top

    @top.setter
    def top(self, value):
        self.application.Top = value

    @property
    def undo_redo_lock(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | UndoRedoLock
                | o Property UndoRedoLock() As
                | 
                | Returns or sets the application status about Undo/Redo. True if the
                | Undo/Redo mechanism is locked.  False is the default. Since Undo/Redo
                | mechanism uses lots of memory, it can be useful to disable it during
                | consuming operations. Then Undo and Redo stacks are flushed and no
                | model modification is kept until the Undo/Redo mechanism is unlocked.
                | It is mandatory to unlock it before the end of the macro.
                |
                | Example:
                | This example disables Undo/Redo mechanism until it is unlocked.
                | CATIA.UndoRedoLock = True

        :return: bool
        """
        return self.application.UndoRedoLock

    @undo_redo_lock.setter
    def undo_redo_lock(self, value):
        self.application.UndoRedoLock = value

    @property
    def visible(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Visible
                | o Property Visible() As
                | 
                | Returns or sets the application's window visibility. True if the
                | application's window is visible to the end user.
                |
                | Example: This
                | example makes the CATIA application's window visible.
                | CATIA.Visibility = True

        :return: bool
        """
        return self.application.Visible

    @visible.setter
    def visible(self, value):
        """
        :param bool value:
        """
        self.application.Visible = value

    @property
    def width(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Width
                | o Property Width() As
                | 
                | Returns or sets the width of the application's frame window. The width
                | is expressed in pixels.
                |
                | Example:
                | This example sets the width of the CATIA application's frame window to 350 pixels.
                | CATIA.Width = 350

        :return: int
        """
        return self.application.Width

    @width.setter
    def width(self, value):
        self.application.width = value

    @property
    def windows(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Windows
                | o Property Windows() As   (Read Only)
                | 
                | Returns the collection of windows currently managed by the
                | application.
                | Example:
                | This example retrieves in WinCollection the
                | collection of windows currently managed by the CATIA application.
                | Dim WinCollection As Windows
                | Set WinCollection = CATIA.Windows

        :return:
        """
        return self.application.Windows

    def create_send_to(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | CreateSendTo
                | o Func CreateSendTo() As
                | 
                | Creates a Send TO.  Role:This method creates a  instance. Warning :
                | CATIASendToService interface requires  the installation of CATIA - PPR
                | xPDM Gateway 1 Product (PX1) In case this product is not granted, the
                | first invocation to one of CATIASendToService methods will fail.

        :return:
        """
        return self.application.CreateSendTo()

    def disable_new_undo_redo_transaction(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | DisableNewUndoRedoTransaction
                | o Sub DisableNewUndoRedoTransaction()
                | 
                | Prevents new Undo/Redo transaction creation.  If too many Undo/Redo
                | transactions are created during macro execution, it may affect
                | performance. So it is valuable to prevent Undo/Redo transaction
                | creation during macro execution when lots of data are created, deleted
                | or modified. Note: preventing Undo/Redo transaction creation must not
                | be done when a selection is required in the macro  Do not forget to
                | call  at the end of the macro or before selection to restore the
                | common behavior.
                |
                | Example:
                | This example prevents new transactions to
                | be created, which may increase performance.
                | CATIA.DisableNewUndoRedoTransaction()

        :return:
        """
        return self.application.DisableNewUndoRedoTransaction()

    def enable_new_undo_redo_transaction(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | EnableNewUndoRedoTransaction
                | o Sub EnableNewUndoRedoTransaction()
                | 
                | Allows new Undo/Redo transaction creation.
                |
                | Example: This example
                | restores the common behavior after  has been called.
                | CATIA.EnableNewUndoRedoTransaction()

        :return:
        """
        return self.application.EnableNewUndoRedoTransaction()

    def execute_script(
            self, library_name, library_type, program_name, function_name, items
    ):
        """

        .. note::
            CAA V5 Visual Basic help

            | Func ExecuteScript( CATBSTR  iLibraryName,
            |   CatScriptLibraryType  iType,
            |   CATBSTR  iProgramName,
            |   CATBSTR  iFunctionName,
            |   CATSafeArrayVariant  iParameters) As CATVariant
            |
            | Executes a scripted function.
            | Parameters:
            |   iLibraryName
            |       The library in which the script is contained
            |   iLibraryType
            |       The type of the library
            |   iProgramName
            |       The name of the program in the library
            |   iFunctionName
            |       The name of the function to invoke
            |   iParameters
            |       An array of parameters for the function
            |   Result
            |       The value returned by the function (if any)
            |
            | Example:
            | This example executes the function CATMain in the program Macro1.catvbs contained by Part1.CATPart
            |   Dim params()
            |   CATIA.SystemService.ExecuteScript"Part1.CATPart",
            |       catScriptLibraryTypeDocument,
            |       "Macro1.catvbs",
            |       "CATMain",
            |       params

        :param str library_name: Full path to location of catia script.
        :param int library_type:  An integer representing the library type selection from list()
         CatScriptLibraryType[catScriptLibraryTypeDocument, catScriptLibraryTypeDirectory,
         catScriptLibraryTypeVBAProject]
        :param str program_name: file name of script.
        :param str function_name: Name of function to call within script.
        :param list items: List of items to pass to script.
        :return:
        """

        run = self.com_object.SystemService.ExecuteScript(
            library_name, library_type, program_name, function_name, items
        )

        return run

    def evaluate(
            self, vba_code, function_name, measurable_items, cat_script_language=0
    ):
        """

        .. note::
            CATIA V5 Visual Basic help

            | Func Evaluate( CATBSTR  iScriptText,
            |       CATScriptLanguage  iLanguage,
            |       CATBSTR  iFunctionName,
            |       CATSafeArrayVariant  iParameters) As CATVariant
            |
            | Evaluates a scripted function.
            | Parameters:
            |   iScriptText
            | The program text
            |   iLanguage
            | The language the program is written in
            |   iFunctionName
            | The name of the function to invoke
            |   iParameters
            | An array of parameters for the function
            |   Result
            | The value returned by the function (if any)
            | Example:
            | This example executes the function CATMain from the CodeToEvaluate string
            |   Dim params()
            |   Dim codeToEvaluate
            |   CodeToEvaluate = "Sub CATMain()" & vbNewLine & _
            |                   "MsgBox " & chr(34) & "Hello World" & chr(34) & vbNewLine & _
            |                   "End Sub"
            |   CATIA.SystemService.Evaluate CodeToEvaluate, CATVBScriptLanguage, "CATMain", params


        :param str vba_code: String containing script to run.
        :param str function_name: Name of function within vba script.
        :param list measurable_items: list of items to pass to script.
        :param int cat_script_language: An integer representing the language selection from list()
         [CATVBScriptLanguage, CATVBALanguage, CATBasicScriptLanguage, CATJavaLanguage,
         CATJScriptLanguage]
        :return:
        """

        run = self.application.SystemService.Evaluate(
            vba_code, cat_script_language, function_name, measurable_items,
        )

        return run

    def file_selection_box(self, i_title, i_extension, i_mode):
        """
        .. note::
            CAA V5 Visual Basic help

                | FileSelectionBox
                | o Func FileSelectionBox(iTitle,
                |                         iExtension,
                |                         iMode) As
                |
                | Displays a modal dialog box which can be used to select / enter the
                | name of a file to open / save.
                |
                | Parameters:
                | iTitle
                |  The title of the dialog box.
                | iExtension
                |   A file extension filter.
                | iMode
                |   The mode in which to run the dialog box (either CatFileSelectionModeOpen or
                |   CatFileSelectionModeSave.
                | oFilePath
                |   The return string containing the full path of the selected file, or a zero-length
                |   string if the user selects Cancel.
                |
                | Examples:
                | This example asks the user to select a text file and prints the path of the selected
                | file.
                | filepath = CATIA.FileSelectionBox("Select a text file", "/\*.txt", CatFileSelectionModeOpen)
                | CATIA.SystemServices.Print "The selected file is " & filepath

        :param i_title:
        :param i_extension:
        :param i_mode:
        :return:
        """
        return self.application.FileSelectionBox(i_title, i_extension, i_mode)

    def get_workbench_id(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetWorkbenchId
                | o Func GetWorkbenchId() As
                | 
                | Returns the identifier of the CATIA current workbench.
                |
                | Parameters:
                | WoworkbenchId
                |   The id of the current workbench.

        :return:
        """
        return self.application.GetWorkbenchId()

    def help(self, i_help_id):
        """
        .. note::
            CAA V5 Visual Basic help

                | Help
                | o Sub Help(iHelpID)
                | 
                | Displays application's online help.
                |
                | Parameters:
                | iHelpID
                |    Identifier of the help message to display
                |
                | Examples:
                | This example displays the string referred to by the HelpKey
                | message key in the message catalog concatenation.
                | 
                | CATIA.Help("HelpKey")

        :param i_help_id:
        :return:
        """
        return self.application.Help(i_help_id)

    def quit(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Quit
                | o Sub Quit()
                | 
                | Exits the application and closes all open documents.
                | Example: This example exits the CATIA application
                | and closes all its open documents.
                | CATIA.Quit()

        :return:
        """
        return self.application.Quit()

    def start_command(self, i_command_id):
        """
        .. note::
            CAA V5 Visual Basic help

                | StartCommand
                | o Sub StartCommand(iCommandId)
                | 
                | Starts a CATIA command. Role:This method starts a command and executes
                | it until its first interaction. Please notice interactions such as
                | selections you could add after in your macro will not work.
                | StartCommand is useful to execute one-shot (not interactive) commands,
                | it is not safe for interactive commands.
                |
                | Parameters:
                | iCommandId
                |  The id of the command to be started. This id can be the name of the 
                |  command or its alias.

        :param i_command_id:
        :return:
        """
        return self.application.StartCommand(i_command_id)

    def start_workbench(self, iworkbench_id):
        """
        .. note::
            CAA V5 Visual Basic help

                | StartWorkbench
                | o Sub StartWorkbench(iworkbenchId)
                | 
                | Starts a CATIA workbench.
                |
                | Parameters:
                | iworkbenchId
                |  The id of the workbench to be started.

        :param iworkbench_id:
        :return:
        """
        return self.application.StartWorkbench(iworkbench_id)

    def __repr__(self):
        return f'Application(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.knowledge_interfaces.dimension import Dimension
from pycatia.in_interfaces.reference import Reference


class Constraint(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | A geometric constraint set for geometric elements of a part, a sketch,
                | or a product.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.constraint = com_object

    @property
    def angle_sector(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | AngleSector
                | o Property AngleSector() As CatConstraintAngleSector
                | 
                | Returns or sets the constraint angle (or angular) sector. The
                | geometric elements of an angle constraint         (e.g. : 2 lines or 2
                | planes) divide the sketch or the space in 4 regions which are called
                | angle or angular sectors, numbered from 0 to 3.        1  / 0 ---/---
                | 2/   3 By default, the constraint is created in the sector number 0.
                | One angle sector corresponds exactly to particular values  of the
                | Dimension.Value, the Side and the Orientation. When changing the angle
                | sector, the Dimension.Value,  Side and Orientation are also modified.


                | Parameters:
                | AngleSector=0
                |     The default sector of a constraint.      
                |         Dimension.Value = angle 
                |         Orientation     = catCstOrientSame
                |         Side            = catCstSidePositive
                |  
                |  AngleSector=1
                |         Dimension.Value = angle-180 if angle>180
                |                          abs(angle)+180 otherwise
                |         Orientation     = catCstOrientOpposite
                |         Side            = catCstSidePositive
                |  
                |  AngleSector=2
                |         Dimension.Value = abs(540-angle) if angle>180
                |                          180-fabs(angle) otherwise
                |         Orientation     = catCstOrientOpposite
                |         Side            = catCstSideNegative
                |  
                |  AngleSector=3
                |         Dimension.Value = 360-abs(angle)
                |         Orientation     = catCstOrientSame
                |         Side            = catCstSideNegative


                | Examples:
                | 
                | The following example retrieves in angleSector
                | the angle sector of the angleCst angle constraint
                | and then changes the angle sector
                | 
                | angleSector = angleCst.AngleSector
                | angleCst.AngleSector = 2

        :return: int
        """
        return self.constraint.AngleSector

    @property
    def dimension(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Dimension
                | o Property Dimension() As Dimension
                | 
                | Returns the constraint dimension. The dimension may be meaningless for
                | some types of constraints  such as tangency constraints,  or if the
                | constraint is not currently satisfied. Use the
                | activateLinkAnchor('','Status','Status')  property to check whether
                | the constraint is  satisfied.  Example:The following example returns
                | in cstDimension the dimension  of the firstCst constraint:  Set
                | cstDimension = firstCst.Dimension


                | Parameters:


        """
        return Dimension(self.constraint.Dimension)

    @property
    def distance_config(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | DistanceConfig
                | o Property DistanceConfig() As CatConstraintDistConfig
                | 
                | Returns or sets the distance constraint configuration. Distance
                | constraints between lines and cylinders offer  often more degrees of
                | freedom to geometry than acually desired. This property allows to
                | limit these degrees of freedom without  having to redefine additional
                | constraints. This property is useless for constraints whose type is
                | not distance.   Example:The following example retrieves in
                | distCstConfig the configuration of the distCst distance constraint:
                | distCstConfig = distCst.DistanceConfig


                | Parameters:

        :return: int
        """
        return self.constraint.DistanceConfig

    @property
    def distance_direction(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | DistanceDirection
                | o Property DistanceDirection() As CatConstraintDistDirection
                | 
                | Returns or sets the distance constraint direction. This property is
                | useless for constraints whose type is not Distance (1). Distance
                | constraints may be measured along a particular direction. This
                | property will be  used if the direction is a reference axis : In 2D, 1
                | means the horizontal axis, 2 the vertical axis.   In 3D, 1 stands for
                | the X axis, 2 for the Y axis, 3 for the Z axis. 0 means that no
                | direction is specified and the distance is measured as usual.
                | Example:The following example retrieves in distCstDirection the
                | configuration of the distCst distance constraint:  distCstConfig =
                | distCst.DistanceDirection


                | Parameters:

        :return: int
        """
        return self.constraint.DistanceDirection

    @property
    def mode(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Mode
                | o Property Mode() As CatConstraintMode
                | 
                | Returns or sets the constraint driving  mode.  For constraint types
                | supporting the concept of value, such as distance  constraints, the
                | driving mode tells whether the constraint value actually drives the
                | geometry position, or, conversely, is driven  by it.  Example:The
                | following example retrieves in currentMode the driving mode for the
                | distCst distance constraint:   currentMode = distCst.Mode


                | Parameters:

        :return: int
        """
        return self.constraint.Mode

    @property
    def orientation(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Orientation
                | o Property Orientation() As CatConstraintOrientation
                | 
                | Returns or sets the constraint orientation. This is used for
                | constraints that involve  two  geometric elements and specifies the
                | orientation for the second geometric element with regard to the first
                | one, when several  possible orientations are all satisfying the
                | constraint.    Example:The following example retrieves the in
                | distCstOrient the orientation of the distCst distance constraint:
                | distCstOrient = distCst.Orientation


                | Parameters:

        :return: int
        """
        return self.constraint.Orientation

    @property
    def reference_axis(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | ReferenceAxis
                | o Property ReferenceAxis() As CatConstraintRefAxis
                | 
                | Returns or sets the constraint reference axis. AxisParallel or
                | AxisPerpendicular constraint types define which axis they relate to
                | through this property,  which makes no sense for constraints of
                | another type.  Example:The following example retrieves in refAxis the
                | reference axis for the axisPerpCst AxisPerpendicular constraint:
                | refAxis = axisPerpCst.ReferenceAxis


                | Parameters:

        :return: int
        """
        return self.constraint.ReferenceAxis

    @property
    def reference_type(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | ReferenceType
                | o Property ReferenceType() As CatConstraintRefType
                | 
                | Returns or sets the constraint reference type. This property is used
                | only for Reference constraints in the Assembly context.  Example:The
                | following example applies to the reference constraint refCst2 the
                | reference type of the constraint refCst1.   refCst2.ReferenceType =
                | refCst1.ReferenceType


                | Parameters:

        :return: int
        """
        return self.constraint.ReferenceType

    @property
    def side(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Side
                | o Property Side() As CatConstraintSide
                | 
                | Returns or sets the constraint side.  Some constraint types need to
                | relatively position the constrained geometries, when several possible
                | configurations are all satisfying the constraint.   Example:The
                | following example retrieves in distCstSide the side of the distCst
                | distance constraint:   distCstSide = distCst.Side


                | Parameters:

        :return: int
        """
        return self.constraint.Side

    @property
    def status(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Status
                | o Property Status() As CatConstraintStatus
                | 
                | Returns the constraint status. The constraint status is a diagnosis on
                | whether the constraint is satisfied.  Example:The following example
                | retrieves the status of the distCst distance constraint.   distCstSts
                | = distCst.Status


                | Parameters:

        :return: int
        """
        return self.constraint.Status

    @property
    def type(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Type
                | o Property Type() As CatConstraintType
                | 
                | Returns the  constraint type.  Example:The following example returns
                | in cstType the type  of the firstCst constraint:  cstType =
                | firstCst.Type


                | Parameters:

        :return: int
        """
        return self.constraint.Type

    def activate(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Activate
                | o Sub Activate()
                | 
                | Unsuppresses a constraint for the update process. An activated
                | constraint is again taken into account  for the calculation of the
                | part or product. Example:The following example es the pad1 pad:
                | Example:The following example activates the tangencyCst constraint :
                | tangencyCst.Activate

        """
        self.constraint.Activate()

    def deactivate(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Deactivate
                | o Sub Deactivate()
                | 
                | Suppresses the constraint from being updated. A deactivated constraint
                | is not taken into account  for the calculation of the part or of the
                | product.

        """
        self.constraint.Deactivate()

    def get_constraint_element(self, i_element_number):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetConstraintElement
                | o Func GetConstraintElement(    long    iElementNumber) As Reference
                | 
                | Reads an element of a constraint.


                | Parameters:
                | iElementNumber
                |    The number of the element of the constraint to be read.
                |    (1 for the first element,2 for the second, 3 for the third).
                |    Notice it must not exceed the total number of elements of the constraint.
                |    (eg : not allowed to read the third element of a tangency).
                |   
                |  
                |   oCurrentElement
                |    An element of the constraint.


                | Examples:
                | 
                | The following example reads the first element of a constraint
                | 
                | Dim reference1 As Reference
                | reference1=tangencyCst.GetConstraintElement( 1 )
                | 
                | 
                | 
        """
        return Reference(self.constraint.GetConstraintElement(i_element_number))

    def get_constraint_visu_location(self, o_anchor_point, o_anchor_vector):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetConstraintVisuLocation
                | o Sub GetConstraintVisuLocation(    CATSafeArrayVariant    oAnchorPoint,
                |                                     CATSafeArrayVariant    oAnchorVector)
                | 
                | Returns the constraint visualisation location. When displayed on
                | screen, the constraint is visualized as  a dimension positioned close
                | to the constrained geometric element(s). This method retrieves the
                | data used to position this representation within the 3D space.


                | Parameters:
                | oAnchorPoint
                |    A Safe Array made up of 3 doubles: X, Y, Z, representing the 
                |    coordinates in model space of the point where the constraint value 
                |    is displayed.
                |  
                |  oAnchorVector
                |      A Safe Array made up of 3 doubles : X, Y, Z, representing the 
                |    vector normal to the plane onto which the constraint value 
                |    is displayed.


                | Examples:
                | 
                | The following example retrieves in anchorPt the anchor point
                | of the tangencyCst tangency constraint:
                | 
                | Dim anchorPoint(2)
                | Dim anchorVector(2)
                | tangencyCst.ConstraintVisuLocation anchorPoint,vectorPoint

        :return: tuple
        """
        return self.constraint.GetConstraintVisuLocation(o_anchor_point, o_anchor_vector)

    def is_inactive(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | IsInactive
                | o Func IsInactive() As boolean
                | 
                | Indicates whether a constraint is suppressed from the update process.
                | A suppressed constraint is not taken into account for the calculation
                | of part or  the product. The method returns True if the constraint is
                | not active,  False if the constraint is active. Example:The following
                | example returns in isInactive whether the tangencyCst constraint is
                | suppressed from the update process:  Set isInactive =
                | tangencyCst.IsInactive

        :return: bool
        """
        return self.constraint.IsInactive()

    def set_constraint_element(self, i_element_number, i_new_element):
        """
        .. note::
            CAA V5 Visual Basic help

                | SetConstraintElement
                | o Sub SetConstraintElement(    long    iElementNumber,
                |                                Reference    iNewElement)
                | 
                | Replaces an element of a constraint.


                | Parameters:
                | iElementNumber
                |    The number of the element of the constraint to replace.
                |    (1 for the first element,2 for the second, 3 for the third).
                |   
                |  
                |   iNewElement
                |    A new element of the constraint.


                | Examples:
                | 
                | The following example changes the second element of a constraint
                | 
                | Dim reference1 As Reference
                | tangencyCst.SetConstraintElement ( 2, reference1)

        :param int i_element_number:
        :param Reference() i_new_element:
        """
        return self.constraint.SetConstraintElement(i_element_number, i_new_element.com_object)

    def set_constraint_visu_location(self, i_new_x, i_new_y, i_new_z):
        """
        .. note::
            CAA V5 Visual Basic help

                | SetConstraintVisuLocation
                | o Sub SetConstraintVisuLocation(    double    iNewX,
                |                                     double    iNewY,
                |                                     double    iNewZ)
                | 
                | Sets a new location for the constraint visualization.


                | Parameters:
                | iNewX
                |    The new value for the constraint anchor point X coordinate
                |  
                |   iNewY
                |    The new value for the constraint anchor point Y coordinate
                |  
                |   iNewZ
                |    The new value for the constraint anchor point Z coordinate


                | Examples:
                | 
                | The following example changes the anchor point coordinates to 10,0,0
                | 
                | tangencyCst.SetConstraintVisuLocation 10,0,0

        :param float i_new_x:
        :param float i_new_y:
        :param float i_new_z:
        """
        return self.constraint.SetConstraintVisuLocation(i_new_x, i_new_y, i_new_z)

    def __repr__(self):
        return f'Constraint()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.sketcher_interfaces.sketch import Sketch
from pycatia.system_interfaces.collection import Collection
from .boundary import Boundary


class Sketches(Collection):
    """
        .. note::
            CAA V5 Visual Basic help
                | The body's collection of sketches not yet used by any shape.

    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Sketch)
        self.sketches = com_object

    def add(self, i_plane):
        """
        .. note::
            CAA V5 Visual Basic help

                | Add
                | o Func Add(    Reference    iPlane) As Sketch
                |
                | Creates a new sketch and adds it to the sketch collection. The sketch
                | creation implies to specify a supporting plane. Once created, the
                | sketch exists, but is empty. You must use the
                | activateLinkAnchor('Sketch','OpenEdition','Sketch.OpenEdition')
                | method to begin to edit it.
                |
                | Parameters:
                | iPlane
                |    The sketch supporting plane
                |  The following
                |
                |  activateLinkAnchor('Boundary','','Boundary')  object is supported:
                |  activateLinkAnchor('PlanarFace','','PlanarFace') .
                |    Returns:
                |   oNewSketch   The created sketch
                |
                | Examples:
                | This example creates the newSketch sketch on the XY plane
                | of the myPart part:
                | Set XYPlane = myPart.OriginElements.PlaneXY()
                | Set newSketch = myPart.Sketches.Add(XYPlane)

        :param Reference i_plane:
        :return Sketch:
        """
        return self.child_object(self.sketches.Add(i_plane))

    def get_boundary(self, i_label):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetBoundary
                | o Func GetBoundary(    CATBSTR    iLabel) As Boundary
                | 
                | Returns a boundary using its label.
                |
                | Parameters:
                | iLabel
                |    Identification of the 
                | 
                |  activateLinkAnchor('Boundary','','Boundary')  object.   See 
                |  activateLinkAnchor('Reference','DisplayName','Reference.DisplayName') . 
                |    Returns:
                |   The retrieved boundary

        """
        return Boundary(self.sketches.GetBoundary(i_label))

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(    CATVariant    iIndex) As Sketch
                | 
                | Returns a sketch using its index or its name from the Sketches
                | collection.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the sketch to retrieve from
                |    the collection of sketches.
                |    As a numeric, this index is the rank of the sketch
                |    in the collection.
                |    The index of the first sketch in the collection is 1, and
                |    the index of the last sketch is Count.
                |    As a string, it is the name you assigned to the sketch using
                |    the 
                | 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property. 
                |    Returns:
                |   The retrieved sketch
                |
                | Examples:
                | This example retrieves the last item in the collection sketches.
                | Set lastSketch = sketchList.Item(sketchList.Count)

        :return: Sketch()
        """
        return self.child_object(self.sketches.Item(i_index))

    def __repr__(self):
        return f'Sketches(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25

from pycatia.system_interfaces.any_object import AnyObject


class Shape(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | Represents the Shape object.It is an abstract object which is not
                | intended to be created as such, from which all objects having a shape
                | representation derive.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.shape = com_object

    def __repr__(self):
        return f'Shape(name={self.name})'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-18 10:56:40.651039

from pycatia.system_interfaces.any_object import AnyObject


class Move(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | Represents an object associated with any kind of objects which
                | retrieves the corresponding movable object.An object can be moved only
                | if it is independent from other objects. For example, a pad can be
                | moved, and is as such a movable object, while an edge cannot be moved
                | individually. It should be moved with all the objects making up the
                | pad to which it belongs as a whole. In this case, the underlying
                | edge's movable object is the pad.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.move = com_object

    @property
    def movable_object(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | MovableObject
                | o Property MovableObject() As   (Read Only)
                | 
                | Returns the movable object associated with the used object.
                | Example: This example retrieves the myMovableObject from
                | Move object associated with MyObject. Dim myMovableObject As
                | Move Set myMovableObject = MyObject.Move.MovableObject
                |

        :return:
        """
        return Move(self.move.MovableObject)

    def apply(self, i_transformation_array):
        """
        .. note::
            CAA V5 Visual Basic help

                | Apply
                | o Sub Apply(iTransformationArray)
                | 
                | Applies a move transformation to a movable object.
                |
                | Parameters:
                | TransformationArray
                |    The linear transformation array initialized successively by the
                |    four columns of the transformation matrix.
                |    The first nine components represent the rotation matrix.
                |    The last three components represent the translation vector.
                |
                | Examples:
                | This example applies the transformation (45 degrees-rotation
                | around the x axis and a translation) stored in
                | TransformationArray to the Move object associated with
                | myMovableObject:
                | Dim TransformationArray( 11 )
                | 'Rotation( 45 degrees around the x axis) components
                | TransformationArray( 0 ) = 1.000
                | TransformationArray( 1 ) = 0
                | TransformationArray( 2 ) = 0
                | TransformationArray( 3 ) = 0
                | TransformationArray( 4 ) = 0.707
                | TransformationArray( 5 ) = 0.707
                | TransformationArray( 6 ) = 0
                | TransformationArray( 7 ) = -0.707
                | TransformationArray( 8 ) = 0.707
                | 'Translation Vector (10,20,30)
                | TransformationArray( 9 ) = 10.000
                | TransformationArray( 10 ) = 20.000
                | TransformationArray( 11 ) = 30.000
                | MyMovableObject.Move.Apply TransformationArray

        :param i_transformation_array:
        :return:
        """
        self.move.Apply(i_transformation_array)

    def __repr__(self):
        return f'Move()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-22 12:54:36.956119

from .shape import Shape


class ShapeInstance(Shape):
    """
        .. note::
            CAA V5 Visual Basic help

                | The interface to access a CATIAShapeInstance.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.shape_instance = com_object

    @property
    def inputs_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | InputsCount
                | o Property InputsCount() As   (Read Only)
                | 
                | Returns the number of Inputs. 
                |
                | Example:
                | The following example
                | retrieves in inputsCount the number of Inputs of
                | hybridShapeInstance: inputsCount =
                | hybridShapeInstance.InputsCount

        :return: int
        """
        return self.shape_instance.InputsCount

    @property
    def outputs_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | OutputsCount
                | o Property OutputsCount() As   (Read Only)
                | 
                | Returns the number of Outputs. 
                |
                | Example:
                | The following
                | example retrieves in outputsCount the number of Outputs of
                | hybridShapeInstance: outputsCount =
                | hybridShapeInstance.OutputsCount

        :return: int
        """
        return self.shape_instance.OutputsCount

    @property
    def parameters_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | ParametersCount
                | o Property ParametersCount() As   (Read Only)
                | 
                | Returns the number of Parameters. 
                |
                | Example:
                | The following
                | example retrieves in parametersCount the number of
                | parameters of hybridShapeInstance: parametersCount =
                | hybridShapeInstance.ParametersCount

        :return: int
        """
        return self.shape_instance.ParametersCount

    def get_input(self, i_name):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInput
                | o Func GetInput(iName) As
                | 
                | Gets an input of a shape instance by its name.
                |
                | Parameters:
                | iName
                |    The name of the input of the shape instance
                |  
                |  Returns:
                |      The input, if found
                |
                | Examples:
                | The following example tests if the input was found: Set
                | input = shapeInstance.GetInput("Input1") If
                | TypeName(input)="Nothing" Then MsgBox "Input not found" End
                | If

        :param str i_name:
        :return: AnyObject()
        """
        return self.shape_instance.GetInput(i_name)

    def get_input_data(self, i_name):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInputData
                | o Func GetInputData(iName) As
                | 
                | Gets an input of a shape instance by its name. Use this
                | method if you want to retrieve a Reference.
                |
                | Parameters:
                | iName
                |    The name of the input of the shape instance
                |  
                |  Returns:
                |      The input, if found
                |
                | Examples:
                | The following example tests if the input was found: Set
                | input = shapeInstance.GetInput("Input1")
                | If TypeName(input)="Nothing"
                |   Then MsgBox "Input not found"
                | End If

        :param str i_name:
        :return:
        """
        return self.shape_instance.GetInputData(i_name)

    def get_input_data_from_position(self, i_position):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInputDataFromPosition
                | o Func GetInputDataFromPosition(iPosition) As
                | 
                | Gets an input of a hybrid shape instance from its position.
                | Use this method if you want to retrieve a Reference.
                |
                | Parameters:
                | iPosition
                |    The position 
                |  
                |  Returns:
                |      The input, if found
                |
                | Examples:
                | The following example tests if the input was found:
                | Set input = hybridShapeInstance.GetInputFromPosition(2)
                | If TypeName(input)="Nothing"
                |   Then MsgBox "Input not found"
                | End If

        :param str i_position:
        :return:
        """
        return self.shape_instance.GetInputDataFromPosition(i_position)

    def get_input_from_position(self, i_position):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInputFromPosition
                | o Func GetInputFromPosition(iPosition) As
                | 
                | Gets an input of a hybrid shape instance from its position.
                |
                | Parameters:
                | iPosition
                |    The position 
                |  
                |  Returns:
                |      The input, if found
                |
                | Examples:
                | The following example tests if the input was found:
                | Set input = hybridShapeInstance.GetInputFromPosition(2)
                | If TypeName(input)="Nothing"
                |   Then MsgBox "Input not found"
                | End If

        :param str i_position:
        :return:
        """
        return self.shape_instance.GetInputFromPosition(i_position)

    def get_output(self, i_name):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetOutput
                | o Func GetOutput(iName) As
                | 
                | Gets a Ouput by its name.
                |
                | Parameters:
                | iName
                |    The name of the output of the shape instance
                |  
                |  Returns:
                |   	 The output, if found
                |
                | Examples:
                | The following example tests if the output was found: Set
                | output = shapeInstance.GetOuput("Output1") If
                | TypeName(output)="Nothing" Then MsgBox "Output not found"
                | End If

        :param str i_name:
        :return:
        """
        return self.shape_instance.GetOutput(i_name)

    def get_output_from_position(self, i_position):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetOutputFromPosition
                | o Func GetOutputFromPosition(iPosition) As
                | 
                | Gets a Ouput from its position.
                |
                | Parameters:
                | iPosition
                |    The position 
                |  
                |  Returns:
                |   	 The output, if found
                |
                | Examples:
                | The following example tests if the output was found: 
                | Set output = shapeInstance.GetOuputFromPosition(2) 
                | If TypeName(output)="Nothing" 
                |   Then MsgBox "Output not found"
                | End If

        :param str i_position:
        :return:
        """
        return self.shape_instance.GetOutputFromPosition(i_position)

    def get_parameter(self, i_name):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetParameter
                | o Func GetParameter(iName) As
                | 
                | Gets a parameter of a shape instance by its name.
                |
                | Parameters:
                | iName
                |    The name of the parameter of the shape instance
                |  
                |  Returns:
                |   	 The parameter, if found
                |
                | Examples:
                | The following example tests if the parameter was found: 
                | Set parameter = shapeInstance.GetParameter("Parameter1") 
                | If TypeName(parameter)="Nothing" 
                |   Then MsgBox "Parameter not found" 
                | End If

        :param str i_name:
        :return:
        """
        return self.shape_instance.GetParameter(i_name)

    def get_parameter_from_position(self, i_position):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetParameterFromPosition
                | o Func GetParameterFromPosition(iPosition) As
                |
                | Gets a parameter of a hybrid shape instance from its
                | position.
                |
                | Parameters:
                | iPosition
                |    The position
                |
                |  Returns:
                |      The parameter, if found
                |
                | Examples:
                | The following example tests if the parameter was found:
                | Set parameter = hybridShapeInstance.GetParameterFromPosition(2)
                | If TypeName(input)="Nothing"
                | Then MsgBox "Parameter not found"
                | End If

        :param str i_position:
        :return:
        """
        return self.shape_instance.GetParameterFromPosition(i_position)

    def put_input(self, i_name, i_input):
        """
        .. note::
            CAA V5 Visual Basic help

                | PutInput
                | o Sub PutInput(iName,
                |                        iInput)
                |
                | Defines an input of a shape instance.
                |
                | Parameters:
                | iName
                |    The input name
                |
                |  iInput
                |    The element wich will be input of the shape instance
                |    All types of
                |
                |  object are possibly supported.
                |
                | Examples:
                | The following example defines the input of a shape instance
                | The input will be a point and its name will be Input1.
                | shapeInstance.PutInput "Input1",point

        :param str i_name:
        :param i_input:
        :return:
        """
        return self.shape_instance.PutInput(i_name, i_input)

    def put_input_data(self, i_name, i_input):
        """
        .. note::
            CAA V5 Visual Basic help

                | PutInputData
                | o Sub PutInputData(iName,
                |                            iInput)
                |
                | Defines an input of a shape instance. Use this method if you
                | want to set as input a Reference.
                |
                | Parameters:
                | iName
                |    The input name
                |
                |  iInput
                |    The element wich will be input of the shape instance
                |    All types of
                |
                |  object are possibly supported.
                |
                | Examples:
                | The following example defines the input of a shape instance
                | The input will be a point and its name will be Input1.
                | shapeInstance.PutInput "Input1",point

        :param str i_name:
        :param i_input:
        :return:
        """
        return self.shape_instance.PutInputData(i_name, i_input)

    def __repr__(self):
        return f'ShapeInstance()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25

from pycatia.system_interfaces.any_object import AnyObject


class OriginElements(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | Represents the part's 3D reference axis system.It allows an easy
                | access to 3D reference axis system of a Part object thru the three
                | planes XY, YZ, and ZX.SeeactivateLinkAnchor('Part','','Part')for
                | parent object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.origin_elements = com_object

    @property
    def plane_xy(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | PlaneXY
                | o Property PlaneXY() As AnyObject  (Read Only)
                | 
                | Returns the XY plane of the part 3D reference axis system.
                |
                | Example:
                | The following example returns in plnXY the XY plane of the partRoot part
                | from the partDoc part document:
                | Set partRoot = partDoc.Part
                | Set plnXY = partRoot.originElements.PlaneXY

        :return: AnyObject()
        """
        return AnyObject(self.origin_elements.PlaneXY)

    @property
    def plane_yz(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | PlaneYZ
                | o Property PlaneYZ() As AnyObject  (Read Only)
                | 
                | Returns the YZ plane of the part 3D reference axis system.
                |
                | Example:
                | The following example returns in plnYZ the YZ plane of the partRoot part
                | from the partDoc part document:
                | Set partRoot = partDoc.Part
                | Set plnYZ = partRoot.originElements.PlaneYZ

        :return: AnyObject()
        """
        return AnyObject(self.origin_elements.PlaneYZ)

    @property
    def plane_zx(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | PlaneZX
                | o Property PlaneZX() As AnyObject (Read Only)
                | 
                | Returns the ZX plane of the part 3D reference axis system. Example:The
                | following example returns in plnZX the ZX plane of the partRoot part
                | from the partDoc part document:  Set partRoot = partDoc.Part Set plnZX
                | = partRoot.originElements.PlaneZX

        :return: AnyObject()
        """
        return AnyObject(self.origin_elements.PlaneZX)

    def __repr__(self):
        return f'OriginElements()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25


class Products:
    """
        .. note::
            CAA V5 Visual Basic help

                | The collection of the Product objects contained in a given Product
                | object of a ProductDocument object.A Product object can aggregate one
                | or zero Products collection.

    """

    def __init__(self, catia):
        self.products = catia.Products

    def add_component(self, i_reference_product):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddComponent
                | o Func AddComponent(    Product    iReferenceProduct) As Product
                | 
                | Creates a component and adds it to the Products collection. A
                | component is a Product object created from another Product object used
                | as reference.


                | Parameters:
                | iReferenceProduct
                |    The product used as reference


                | Examples:
                | 
                | The following example creates the SpareWheel component from
                | the reference product FrontRightWheel and adds the component
                | to the ToolKits collection.
                | 
                | Dim SpareWheel As Product
                | Set SpareWheel = ToolKits.AddComponent(FrontRightWheel)
                | 
                | 
                | 
        """
        # todo: not yet implemented
        return self.products.AddComponent(i_reference_product)

    def add_components_from_files(self, i_files_list, i_method):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddComponentsFromFiles
                | o Sub AddComponentsFromFiles(    CATSafeArrayVariant    iFilesList,
                |                                  CATBSTR    iMethod)
                | 
                | Creates a component for each file. The components are added to the
                | Products collection.


                | Parameters:
                | iFilesList
                |    The paths of the files used to retrieve the reference or the
                |    shape of th component
                |  
                |  iMethod
                |    A string describing the expected type of the files


        """
        # todo: not yet implemented
        return self.products.AddComponentsFromFiles(i_files_list, i_method)

    def add_external_component(self, i_product_document):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddExternalComponent
                | o Func AddExternalComponent(    Document    iProductDocument) As Product
                | 
                | Creates a component from the root product of  another ProductDocument
                | object. This root product is used as a reference to create the
                | component. The component is added to the Products collection.


                | Parameters:
                | iProductDocument
                |    The product document whose root object is to be used as reference
                |    to create the component


                | Examples:
                | 
                | The following example creates the GearBox component by
                | referencing the GearBoxDocument and adds it
                | to the PowerTrains collection.
                | 
                | Dim GearBox As Product
                | Set GearBox = PowerTrains.AddExternalComponent(GearBoxDocument)
                | 
                | 
                | 
        """
        # todo: not yet implemented
        return self.products.AddExternalComponent(i_product_document)

    def add_new_component(self, i_documen_type, i_part_number):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddNewComponent
                | o Func AddNewComponent(    CATBSTR    iDocumenType,
                |                            CATBSTR    iPartNumber) As Product
                | 
                | Creates a component from the root product of  a new ProductDocument
                | object. This root product is used as a reference to create the
                | component. The component is added to the Products collection.


                | Parameters:
                | iProductDocument
                |    The product document whose root object is to be used as reference
                |    to create the component


                | Examples:
                | 
                | The following example creates the GearBox component by
                | referencing the GearBoxDocument and adds it
                | to the PowerTrains collection.
                | 
                | Dim GearBox As Product
                | Set GearBox = PowerTrains.AddNewComponent(GearBoxDocument, "A120-253X-7")
                | 
                | 
                | 
        """
        # todo: not yet implemented
        return self.products.AddNewComponent(i_documen_type, i_part_number)

    def add_new_product(self, i_part_number):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddNewProduct
                | o Func AddNewProduct(    CATBSTR    iPartNumber) As Product
                | 
                | Creates a Product reference object. This creates a Product reference
                | object and the associated component by specifying its type and adds it
                | to the Products collection.


                | Parameters:
                | iPartNumber
                |    The part number of the product to be created and added to the 
                |    to the collection


                | Examples:
                | 
                | The following example creates the Engine product
                | and adds the created component to the PowerTrains collection.
                | 
                | Dim Engine As Product
                | Set Engine = PowerTrains.AddNewProduct(V6Engine)
                | 
                | 
                | 
        """
        # todo: not yet implemented
        return self.products.AddNewProduct(i_part_number)

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(    CATVariant    iIndex) As Product
                | 
                | Returns a product from its index in the Products collection.


                | Parameters:
                | iIndex
                |    The index of the product to retrieve in the collection of products.
                |    This index can either be the rank of the product in the collection
                |    or the name you assign to the product.
                |    As a numeric, this index is the rank of the product
                |    in the collection.
                |    The index of the first product in the collection is 1, and
                |    the index of the last product is Count.
                |    As a string, it is the name you assigned to the product using
                |    the 
                | 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property  
                |    Returns:
                |   The retrieved product


                | Examples:
                | 
                | The following example returns in ThisProduct the third product,
                | and in ThatProduct the product named
                | Wheel in the CarParts product collection.
                | 
                | Dim ThisProduct As Product
                | Set ThisProduct = CarParts.Item(3)
                | Dim ThatProduct As Product
                | Set ThatProduct = CarParts.Item("Wheel")
                | 
                | 
                | 
        """
        # todo: not yet implemented
        return self.products.Item(i_index)

    def remove(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Remove
                | o Sub Remove(    CATVariant    iIndex)
                | 
                | Removes a product from the Products collection.


                | Parameters:
                | iIndex
                |    The index of the product to remove.
                |    This index can either be the rank of the product in the collection
                |    or the name you assigned to the product.
                |    As a numeric, this index is the rank of the product
                |    in the collection.
                |    The index of the first product in the collection is 1, and
                |    the index of the last product is Count.
                |    As a string, it is the name you assigned to the product using
                |    the 
                | 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property


                | Examples:
                | 
                | The following example removes the sixth product and the product named
                | LeftRearDisc from the Brakes product collection.
                | 
                | Brakes.Remove(6)
                | Brakes.Remove("LeftRearDisc")
                | 
                | 
                | 
        """
        # todo: not yet implemented
        return self.products.Remove(i_index)

    def replace_component(self, i_old_component, i_file_path, i_multi_instances):
        """
        .. note::
            CAA V5 Visual Basic help

                | ReplaceComponent
                | o Func ReplaceComponent(    Product    iOldComponent,
                |                             CATBSTR    iFilePath,
                |                             boolean    iMultiInstances) As Product
                | 
                | Creates a component which replace the given one.


                | Parameters:
                | iOldComponent
                |    The component which will be replaced
                |  
                |  iFilePath
                |    the document to replace with
                |  
                |   iMultiInstances
                |    Parameter to set to True if all instances are to be replaced, or to False otherwise. 
                |    Returns the component replacing iOldComponent
                |  Note:
                |    Part Number conflict will be resolved automatically.


        """
        # todo: not yet implemented
        return self.products.ReplaceComponent(i_old_component, i_file_path, i_multi_instances)

    def replace_product(self, i_old_component, i_new_reference, i_multi_instances):
        """
        .. note::
            CAA V5 Visual Basic help

                | ReplaceProduct
                | o Func ReplaceProduct(    Product    iOldComponent,
                |                           Product    iNewReference,
                |                           boolean    iMultiInstances) As Product
                | 
                | Creates a component which replace the given one.


                | Parameters:
                | iOldComponent
                |    The component which will be replaced
                |  
                |  iNewReference
                |    the reference whom the old copmponent will be reconnected
                |  
                |   iMultiInstances
                |    Parameter to set to True if all instances are to be replaced, or to False otherwise. 
                |    Returns the component replacing iOldComponent


        """
        # todo: not yet implemented
        return self.products.ReplaceProduct(i_old_component, i_new_reference, i_multi_instances)



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.collection import Collection
from .body import Body


class Bodies(Collection):
    """
        .. note::
            CAA V5 Visual Basic help

                | A collection of all the Body objects contained in the part.

    """

    def __init__(self, collection_com_object):
        super().__init__(collection_com_object, child_object=Body)
        self.bodies = collection_com_object

    def add(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Add
                | o Func Add() As Body
                | 
                | Creates a new body and adds it to the Bodies collection. This body
                | becomes the current one  Returns:  The created body
                |
                | Example:
                | The following example creates a body names NewBody in the body collection
                | of the rootPart part in the partDoc part document. NewBody becomes the
                | current body in partDoc.
                | Set rootPart = partDoc.Part
                | Set NewBody = rootPart.Bodies.Add()

        """
        return self.child_object(self.bodies.Add())

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(    CATVariant    iIndex) As Body
                | 
                | Returns a body using its index or its name from the Bodies collection.


                | Parameters:
                | iIndex
                |    The index or the name of the body to retrieve from
                |    the collection of bodies.
                |    As a numeric, this index is the rank of the body
                |    in the collection.
                |    The index of the first body in the collection is 1, and
                |    the index of the last body is Count.
                |    As a string, it is the name you assigned to the body using
                |    the 
                | 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property. 
                |    Returns:
                |   The retrieved body
                |
                | Examples:
                | This example retrieves in ThisBody the fifth body
                | in the collection and in ThatBody the body
                | named MyBody in the body collection of the partDoc
                | part document.
                | 
                | Set BodyColl = partDoc.Part.Bodies
                | Set ThisBody = BodyColl.Item(5)
                | Set ThatBody = BodyColl.Item("MyBody")

        :return: Body()
        """
        return self.child_object(self.bodies.Item(i_index))

    def __repr__(self):
        return f'Bodies(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.collection import Collection


class GeometricElements(Collection):
    """
        .. note::
            CAA V5 Visual Basic help

                | A collection of all geometric elements contained in a part or a
                | sketch.Geometric elements are created with the 2D factory for the
                | sketch and with the 3D factory for the part. Geometric elements thus
                | created are then aggregated either in the sketch or as part of the
                | geometric element collection.

    """

    def __init__(self, collection_com_object):
        super().__init__(collection_com_object)
        self.geometric_elements = collection_com_object

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(    CATVariant    iIndex) As GeometricElement
                | 
                | Returns a geometric element using its index or its name from the
                | GeometricElements collection.


                | Parameters:
                | iIndex
                |    The index or the name of the geometric element to retrieve from
                |    the collection of geometric elements.
                |    As a numeric, this index is the rank of the geometric element
                |    in the collection.
                |    The index of the first geometric element in the collection is 1, and
                |    the index of the last geometric element is Count.
                |    As a string, it is the name you assigned to the geometric element using
                |    the 
                | 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property. 
                |    Returns:
                |   The retrieved geometric element


                | Examples:
                | 
                | 
                | This example retrieves the last item in the geometric element collection.
                | 
                | Set lastCst = cstList.Item(cstList.Count)

            see sketcher_interfaces.enumeration_types.geometric_type
            :return: int
        """
        return self.geometric_elements.Item(i_index)

    def __repr__(self):
        return f'GeometricElements()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-22 12:54:36.956119

from .edge import Edge


class MonoDimFeatEdge(Edge):
    """
        .. note::
            CAA V5 Visual Basic help

                | 1-D boundary belonging to a feature whose topological result is one
                | dimensional.Role:
                | ThisactivateLinkAnchor('Boundary','','Boundary')object may be, for
                | example, in a part containing a Sketch which is made up of a circle
                | arc and a spline, the circle arc.  You will create a MonoDimFeatEdge
                | object using theactivateLinkAnchor('Shapes','GetBoundary','Shapes.GetB
                | oundary'),activateLinkAnchor('HybridShapes','GetBoundary','HybridShape
                | s.GetBoundary'),activateLinkAnchor('Sketches','GetBoundary','Sketches.
                | GetBoundary')oractivateLinkAnchor('Selection','SelectElement2','Select
                | ion.SelectElement2')method. Then, you pass it to the operator (such as
                | activateLinkAnchor('HybridShapeFactory','AddNewPointTangent','HybridSh
                | apeFactory.AddNewPointTangent')).  The lifetime of a MonoDimFeatEdge
                | object is limited, seeactivateLinkAnchor('Boundary','','Boundary').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mono_dim_feat_edge = com_object

    def __repr__(self):
        return f'MonoDimFeatEdge(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-22 12:54:36.956119

from pycatia.in_interfaces.move import Move
from .shape import Shape


class Solid(Shape):
    """
        .. note::
            CAA V5 Visual Basic help

                | Represents an imported solid object.Role: the imported solid is a
                | solid obtained from copy/paste with link or design in context.The
                | solid object has a link to a source element obtained
                | fromactivateLinkAnchor('','SourceElement','SourceElement')and a source
                | product obtained
                | fromactivateLinkAnchor('','SourceProduct','SourceProduct').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.solid = com_object

    @property
    def move(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Move
                | o Property Move() As   (Read Only)
                | 
                | Returns the move object of the solid. Role: The move object
                | is aggregated by the solid object and itself aggregates a
                | movable object to which you can apply a move transformation
                | by means of an isometry matrix. It moves the solid according
                | to this isometry. 
                |
                | Example:
                | This example retrieves the move
                | object EngineMoveObject for the Engine product. Dim
                | EngineMoveObject As Move Set EngineMoveObject = Engine.Move
                | See also:

        :return:
        """
        return Move(self.solid.Move)

    @property
    def source_element(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | SourceElement
                | o Property SourceElement() As   (Read Only)
                | 
                | Returns the source element of the imported solid. Role:
                | returns the linked element in the source part. 
                |
                | Example:
                | The
                | following example returns in element the source element of
                | the imported solid importedSolid: Set element =
                | importedSolid.SourceElement

        :return: AnyObject()
        """
        return self.solid.SourceElement

    @property
    def source_product(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | SourceProduct
                | o Property SourceProduct() As   (Read Only)
                | 
                | Returns the source product instance of the imported solid.
                | Role: returns the product instance which was selected when
                | the import was created. 
                |
                | Example:
                | The following example
                | returns in prod1 the source product instance of the imported
                | solid importedSolid: Set prod1 = importedSolid.SourceProduct

        :return: AnyObject
        """
        return self.solid.SourceProduct

    def __repr__(self):
        return f'Solid()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.exception_handling.exceptions import CATIAApplicationException
from pycatia.system_interfaces.collection import Collection
from .boundary import Boundary
from .hybrid_shape import HybridShape


class HybridShapes(Collection):
    """
        .. note::
            CAA V5 Visual Basic help

                | The collection of the HybridShapes making up a body.

    """

    def __init__(self, collection_com_object):
        super().__init__(collection_com_object, child_object=HybridShape)
        self.hybrid_shapes = collection_com_object

    def get_boundary(self, i_label):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetBoundary
                | o Func GetBoundary(    CATBSTR    iLabel) As Boundary
                | 
                | Returns a boundary using its label.


                | Parameters:
                | iLabel
                |    Identification of the 
                | 
                |  activateLinkAnchor('Boundary','','Boundary')  object.   See 
                |  activateLinkAnchor('Reference','DisplayName','Reference.DisplayName') . 
                |    Returns:
                |   The retrieved boundary


        """
        return Boundary(self.hybrid_shapes.GetBoundary(i_label))

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(    CATVariant    iIndex) As HybridShape
                | 
                | Returns a HybridShape using its index or its name from the
                | HybridShapes collection.


                | Parameters:
                | iIndex
                |    The index or the name of the HybridShape to retrieve from
                |    the collection of HybridShapes.
                |    As a numeric, this index is the rank of the HybridShape
                |    in the collection.
                |    The index of the first HybridShape in the collection is 1, and
                |    the index of the last HybridShape is 
                | 
                |  activateLinkAnchor('Collection','Count','Collection.Count') .   As a
                | string, it is the name you assigned to the HybridShape using
                |    the 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property. 
                |    Returns:
                |   The retrieved HybridShape


                | Examples:
                | 
                | 
                | This example retrieves in ThisHybridShape the third HybridShape,
                | and in ThatHybridShape the HybridShape named
                | MyHybridShape in the HybridShape collection of the active document,
                | supposed to be a part document.
                | 
                | Set ThisHybridShape = CATIA.ActiveDocument.HybridShapes.Item(3)
                | Set ThatHybridShape = CATIA.ActiveDocument.HybridShapes.Item("MyHybridShape")
                | 
                | 
                | 
        """
        try:
            return self.child_object(self.hybrid_shapes.Item(i_index))
        except CATIAApplicationException:
            raise CATIAApplicationException('Could not find item.')

    def __repr__(self):
        return f'HybridShapes(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-18 10:56:40.651039

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.product_structure_interfaces.product import Product


class FixTogether(AnyObject):
    """
        .. note::
            CAA V5 Visual Basic help

                | The object that manages a sequence of products or fixTogethers.It
                | belongs to
                | theactivateLinkAnchor('FixTogether','','FixTogether')collection of
                | aactivateLinkAnchor('Product','','Product').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fix_together = com_object

    @property
    def fix_togethers_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | FixTogethersCount
                | o Property FixTogethersCount() As   (Read Only)
                | 
                | Returns the number of FixTogether entities in the
                | FixTogether.
                |
                | Example:
                | The following example retrieves in
                | fixTogethersCount the number of FixTogethers of the
                | myFixTogether FixTogether :
                | fixTogethersCount = myFixTogether.FixTogethersCount

        :return: int
        """
        return self.fix_together.FixTogethersCount

    @property
    def products_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | ProductsCount
                | o Property ProductsCount() As   (Read Only)
                | 
                | Returns the number of products fixed together in the
                | FixTogether. Example: The following example retrieves in
                | productsCount the number of products of the myFixTogether
                | FixTogether : productsCount = myFixTogether.ProductsCount

        :return: int
        """
        return self.fix_together.ProductsCount

    def add_fix_together(self, i_fix_together):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddFixTogether
                | o Sub AddFixTogether(iFixTogether)
                | 
                | Add a fixTogether to a FixTogether. The fixTogether is fixed
                | together with the products or fixTogethers already contained
                | in the FixTogether. Example: The following example adds a
                | FixTogether fixTogether in a FixTogether myFixTogether.
                | myFixTogether.AddFixTogether(fixTogether)
                |
                | Parameters:
                |

        :param FixTogether() i_fix_together:
        :return:
        """
        self.fix_together.AddFixTogether(i_fix_together.com_object)

    def add_product(self, i_product):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddProduct
                | o Sub AddProduct(iProduct)
                | 
                | Add a product to a FixTogether. The product is fixed
                | together with the products and fixTogethers already
                | contained in the FixTogether.

                | Example:
                | The following example
                | adds a Product myProduct in a FixTogether.
                | myFixTogether.AddProduct(myProduct)

        :param Product() i_product:
        :return:
        """
        return self.fix_together.AddProduct(i_product.com_object)

    def get_fix_together(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetFixTogether
                | o Func GetFixTogether(iIndex) As
                | 
                | Returns a FixTogether using its index or its name in the
                | FixTogether.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the FixTogether to retrieve.
                |    As a numerics, this index is the rank of the FixTogether
                |    in the FixTogethers of the FixTogether.
                |    The index of the first FixTogether is 1, and
                |    the index of the last FixTogether is FixTogethersCount.
                |    As a string, it is the name you assigned to the FixTogether using
                |    the property.
                | Returns:
                |    The retrieved FixTogether
                |
                | Examples:
                | This example retrieves in thisFixTogether the fifth
                | FixTogether and in thatFixTogether the FixTogether named
                | myFixTogether in the FixTogethers of the FixTogether.
                | Dim thisFixTogether As FixTogether
                | Set thisFixTogether = myFixTogether.GetFixTogether(5)
                | Dim thatFixTogether As FixTogether
                | Set thatFixTogether = myFixTogether.GetFixTogether("myFixTogether")

        :param i_index:
        :return:
        """

        return FixTogether(self.fix_together.GetFixTogether(i_index))

    def get_product(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetProduct
                | o Func GetProduct(iIndex) As
                | 
                | Returns a Product using its index or its name in the
                | FixTogether.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the Product to retrieve.
                |    As a numerics, this index is the rank of the Product
                |    in the products of the FixTogether.
                |    The index of the first Product is 1, and
                |    the index of the last Product is ProductsCount.
                |    As a string, it is the name you assigned to the Product using
                |    the property.
                | Returns:
                |    The retrieved Product
                |
                | Examples:
                | This example retrieves in thisProduct the fifth Product and
                | in thatProduct the Product named myProduct in the products
                | of the FixTogether.
                | Dim thisProduct As Product
                | Set thisProduct = myFixTogether.GetProduct(5)
                | Dim thatProduct As Product
                | Set thatProduct = myFixTogether.GetProduct("myProduct")

        :param i_index:
        :return:
        """
        return Product(self.fix_together.GetProduct(i_index))

    def remove_fix_together(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | RemoveFixTogether
                | o Sub RemoveFixTogether(iIndex)
                | 
                | Removes a FixTogether from the FixTogether.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the FixTogether to remove from the FixTogether.
                |    As a numerics, this index is the rank of the FixTogether
                |    in the FixTogethers of the FixTogether.
                |    The index of the first FixTogether is 1, and
                |    the index of the last FixTogether is FixTogethersCount.
                |    As a string, it is the name you assigned to the FixTogether using
                |    the property.
                |
                | Examples:
                | This example removes the last FixTogether of the
                | FixTogether.
                | fixTogether.RemoveFixTogether(fixTogether.FixTogethersCount)

        :param int i_index:
        :return:
        """
        self.fix_together.RemoveFixTogether(i_index)

    def remove_product(self, i_index):
        """
        .. warning::

            The index when not a string must be it's python index (indexes in python start from 0).
            collection. The COM interface index starts at 1.

        .. note::
            CAA V5 Visual Basic help

                | RemoveProduct
                | o Sub RemoveProduct(iIndex)
                | 
                | Removes a Product from the FixTogether.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the Product to remove from the FixTogether.
                |    As a numerics, this index is the rank of the Product
                |    in the products of the FixTogether.
                |    The index of the first Product is 1, and
                |    the index of the last Product is ProductsCount.
                |    As a string, it is the name you assigned to the FixTogether using
                |    the 
                | 
                |  property.

                |                | Examples:
                | This example removes the last Product of the FixTogether.
                | fixTogether.RemoveProduct(fixTogether.ProductsCount)

        :param int i_index:
        :return:
        """
        self.fix_together.RemoveProduct(i_index)

    def __repr__(self):
        return f'FixTogether(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.curve2_d import Curve2D


class Line2D(Curve2D):
    """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             SketcherInterfaces.Curve2D
                |                                 Line2D
                | 
                | Class defining a line in 2D Space.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.line2_d = com_object

    def get_direction(self, o_direction):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetDirection(CATSafeArrayVariant oDirection)
                | 
                |     Returns the unit-vector pointing in the direction of the
                |     line.
                | 
                |     Parameters:
                | 
                |         oDirection[0]
                |             The X Coordinate of the unit vector pointing in the direction of
                |             the line 
                |         oDirection[1]
                |             The Y Coordinate of the unit vector pointing in the direction of
                |             the line

        :param tuple o_direction:
        :return: None
        """
        return self.line2_d.GetDirection(o_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_direction'
        # # vba_code = """
        # # Public Function get_direction(line2_d)
        # #     Dim oDirection (2)
        # #     line2_d.GetDirection oDirection
        # #     get_direction = oDirection
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self, o_origin):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Returns a point lying on the line
                | 
                |     Parameters:
                | 
                |         oPoint[0]
                |             The X Coordinate of a point lying on the line 
                |         oPoint[1]
                |             The Y Coordinate of a point lying on the line

        :param tuple o_origin:
        :return: None
        """
        return self.line2_d.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(line2_d)
        # #     Dim oOrigin (2)
        # #     line2_d.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_data(self, i_x, i_y, i_x_direction, i_y_direction):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetData(double iX,
                | double iY,
                | double iXDirection,
                | double iYDirection)
                | 
                |     Modifies the caracteristics of the infinite line
                | 
                |     Parameters:
                | 
                |         iX
                |             The X Coordinate of a point lying on the line 
                |         iY
                |             The Y Coordinate of a point lying on the line 
                |         iXDirection
                |             The X Coordinate of the unit vector pointing in the direction of
                |             the line 
                |         iYDirection
                |             The Y Coordinate of the unit vector pointing in the direction of
                |             the line

        :param float i_x:
        :param float i_y:
        :param float i_x_direction:
        :param float i_y_direction:
        :return: None
        """
        return self.line2_d.SetData(i_x, i_y, i_x_direction, i_y_direction)

    def __repr__(self):
        return f'Line2D(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25


class HybridShapeInstance:
    """
        .. note::
            CAA V5 Visual Basic help

                | The interface to access a CATIAHybridShapeInstance.

    """

    def __init__(self, catia):
        self.hybridshapeinstance = catia.HybridShapeInstance     

    @property
    def inputs_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | InputsCount
                | o Property InputsCount() As long
                | 
                | Returns the number of Inputs.  Example:The following example retrieves
                | in inputsCount the number of Inputs of hybridShapeInstance:
                | inputsCount = hybridShapeInstance.InputsCount


                | Parameters:


        """
        return self.hybridshapeinstance.InputsCount

    @property
    def outputs_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | OutputsCount
                | o Property OutputsCount() As long
                | 
                | Returns the number of Outputs.  Example:The following example
                | retrieves in outputsCount the number of Outputs of
                | hybridShapeInstance:  outputsCount = hybridShapeInstance.OutputsCount


                | Parameters:


        """
        return self.hybridshapeinstance.OutputsCount

    @property
    def parameters_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | ParametersCount
                | o Property ParametersCount() As long
                | 
                | Returns the number of Parameters.  Example:The following example
                | retrieves in parametersCount the number of parameters of
                | hybridShapeInstance:  parametersCount =
                | hybridShapeInstance.ParametersCount


                | Parameters:


        """
        return self.hybridshapeinstance.ParametersCount

    def get_input(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInput
                | o Func GetInput(    CATBSTR    iIndex) As AnyObject
                | 
                | Gets an input of a hybrid shape instance by its name.


                | Parameters:
                | iName
                |    The name of the input of the hybrid shape instance
                |  
                | 
                |  Returns:
                |      The input, if found


                | Examples:
                | 
                | The following example tests if the input was found:
                | 
                | Set input = hybridShapeInstance.GetInput("Input1")
                | If TypeName(input)="Nothing" Then
                | MsgBox "Input not found"
                | End If
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.GetInput(i_index)

    def get_input_data(self, i_name):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInputData
                | o Func GetInputData(    CATBSTR    iName) As CATBaseDispatch
                | 
                | Gets an input of a shape instance by its name. Use this method if you
                | want to retrieve a Reference.


                | Parameters:
                | iName
                |    The name of the input of the shape instance
                |  
                | 
                |  Returns:
                |      The input, if found


                | Examples:
                | 
                | The following example tests if the input was found:
                | 
                | Set input = shapeInstance.GetInput("Input1")
                | If TypeName(input)="Nothing" Then
                | MsgBox "Input not found"
                | End If
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.GetInputData(i_name)

    def get_input_data_from_position(self, i_position):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInputDataFromPosition
                | o Func GetInputDataFromPosition(    long    iPosition) As CATBaseDispatch
                | 
                | Gets an input of a hybrid shape instance from its position. Use this
                | method if you want to retrieve a Reference.


                | Parameters:
                | iPosition
                |    The position 
                |  
                | 
                |  Returns:
                |      The input, if found


                | Examples:
                | 
                | The following example tests if the input was found:
                | 
                | Set input = hybridShapeInstance.GetInputFromPosition(2)
                | If TypeName(input)="Nothing" Then
                | MsgBox "Input not found"
                | End If
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.GetInputDataFromPosition(i_position)

    def get_input_from_position(self, i_position):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetInputFromPosition
                | o Func GetInputFromPosition(    long    iPosition) As AnyObject
                | 
                | Gets an input of a hybrid shape instance from its position.


                | Parameters:
                | iPosition
                |    The position 
                |  
                | 
                |  Returns:
                |      The input, if found


                | Examples:
                | 
                | The following example tests if the input was found:
                | 
                | Set input = hybridShapeInstance.GetInputFromPosition(2)
                | If TypeName(input)="Nothing" Then
                | MsgBox "Input not found"
                | End If
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.GetInputFromPosition(i_position)

    def get_output(self, i_name):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetOutput
                | o Func GetOutput(    CATBSTR    iName) As AnyObject
                | 
                | Gets a Ouput by its name.


                | Parameters:
                | iName
                |    The name of the output of the shape instance
                |  
                | 
                |  Returns:
                |   	 The output, if found


                | Examples:
                | 
                | The following example tests if the output was found:
                | 
                | Set output = shapeInstance.GetOuput("Output1")
                | If TypeName(output)="Nothing" Then
                | MsgBox "Output not found"
                | End If
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.GetOutput(i_name)

    def get_output_from_position(self, i_position):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetOutputFromPosition
                | o Func GetOutputFromPosition(    long    iPosition) As AnyObject
                | 
                | Gets a Ouput from its position.


                | Parameters:
                | iPosition
                |    The position 
                |  
                | 
                |  Returns:
                |   	 The output, if found


                | Examples:
                | 
                | The following example tests if the output was found:
                | 
                | Set output = shapeInstance.GetOuputFromPosition(2)
                | If TypeName(output)="Nothing" Then
                | MsgBox "Output not found"
                | End If
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.GetOutputFromPosition(i_position)

    def get_parameter(self, i_name):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetParameter
                | o Func GetParameter(    CATBSTR    iName) As AnyObject
                | 
                | Gets a parameter of a hybrid shape instance by its name.


                | Parameters:
                | iName
                |    The name of the parameter of the hybrid shape instance
                |  
                | 
                |  Returns:
                |   	 The parameter, if found


                | Examples:
                | 
                | The following example tests if the parameter was found:
                | 
                | Set parameter = hybridShapeInstance.GetParameter("Parameter1")
                | If TypeName(parameter)="Nothing" Then
                | MsgBox "Parameter not found"
                | End If
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.GetParameter(i_name)

    def get_parameter_from_position(self, i_position):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetParameterFromPosition
                | o Func GetParameterFromPosition(    long    iPosition) As AnyObject
                | 
                | Gets a parameter of a hybrid shape instance from its position.


                | Parameters:
                | iPosition
                |    The position 
                |  
                | 
                |  Returns:
                |      The parameter, if found


                | Examples:
                | 
                | The following example tests if the parameter was found:
                | 
                | Set parameter = hybridShapeInstance.GetParameterFromPosition(2)
                | If TypeName(input)="Nothing" Then
                | MsgBox "Parameter not found"
                | End If
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.GetParameterFromPosition(i_position)

    def put_input(self, i_index, i_input):
        """
        .. note::
            CAA V5 Visual Basic help

                | PutInput
                | o Sub PutInput(    CATBSTR    iIndex,
                |                    AnyObject    iInput)
                | 
                | Defines an input of a hybrid shape instance.


                | Parameters:
                | iName
                |    The input name
                |  
                |  iInput
                |    The element wich will be input of the hybrid shape instance
                |    All types of 
                | 
                |  activateLinkAnchor('Boundary','','Boundary')  object are possibly supported.


                | Examples:
                | 
                | The following example defines the input of a hybrid shape instance
                | The input will be a point and its name will be Input1.
                | 
                | hybridShapeInstance.PutInput "Input1",point
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.PutInput(i_index, i_input)

    def put_input_data(self, i_name, i_input):
        """
        .. note::
            CAA V5 Visual Basic help

                | PutInputData
                | o Sub PutInputData(    CATBSTR    iName,
                |                        CATBaseDispatch    iInput)
                | 
                | Defines an input of a shape instance. Use this method if you want to
                | set as input a Reference.


                | Parameters:
                | iName
                |    The input name
                |  
                |  iInput
                |    The element wich will be input of the shape instance
                |    All types of 
                | 
                |  activateLinkAnchor('Boundary','','Boundary')  object are possibly supported.


                | Examples:
                | 
                | The following example defines the input of a shape instance
                | The input will be a point and its name will be Input1.
                | 
                | shapeInstance.PutInput "Input1",point
                | 
                | 
                | 
        """
        return self.hybridshapeinstance.PutInputData(i_name, i_input)




#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.knowledge_interfaces.free_parameter import FreeParameter
from pycatia.system_interfaces.collection import Collection


class FreeParameters(Collection):
    """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FreeParameters
                | 
                | Interface to access a CATIAFreeParameters.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=FreeParameter)
        self.free_parameters = com_object

    def add_free_parameter(self, parameter):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddFreeParameter(RealParam parameter) As
                | FreeParameter
                | 
                |     Adds a free parameter. This parameter must not be read only.

        :param RealParam parameter:
        :return: FreeParameter
        """
        return FreeParameter(self.free_parameters.AddFreeParameter(parameter.com_object))

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As FreeParameter
                | 
                |     Retrieves an optimization using its index or its name from the Free
                |     Parameters collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the free parameter to retrieve from the
                |             collection of free parameters. As a numerics, this index is the rank of the
                |             free parameter in the collection. The index of the first free parameter in the
                |             collection is 1, and the index of the last free parameter is Count. As a
                |             string, it is the name you assigned to the free parameter using the
                |             
                | 
                |         AnyObject.Name property or when changing the free parameter name by the
                |         property panel. 
                |     Returns:
                |         The retrieved free parameter 
                |     Example:
                |         This example retrieves the last free parameter in the free parameters
                |         collection.
                | 
                |          Set lastFreeParameter = freeParameters.Item(freeParameters.Count)

        :param CATVariant i_index:
        :return: FreeParameter
        """
        return FreeParameter(self.free_parameters.Item(i_index))

    def remove_free_parameter(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RemoveFreeParameter(CATVariant iIndex)
                | 
                |     Removes a free parameter.

        :param CATVariant i_index:
        :return: None
        """
        return self.free_parameters.RemoveFreeParameter(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_free_parameter'
        # # vba_code = """
        # # Public Function remove_free_parameter(free_parameters)
        # #     Dim iIndex (2)
        # #     free_parameters.RemoveFreeParameter iIndex
        # #     remove_free_parameter = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'FreeParameters(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.collection import Collection
from .constraint import Constraint


class Constraints(Collection):
    """
        .. note::
            CAA V5 Visual Basic help

                | A collection of all geometric constraints set on a part, a sketch, or
                | a product.A constraint collection is created with default values for
                | its properties (such as value, orientation, etc.). Use the constraint
                | properties  edition services to set them to appropriate values after
                | constraint creation.

    """

    def __init__(self, collection_com_object):
        super().__init__(collection_com_object, child_object=Constraint)
        self.constraints = collection_com_object

    @property
    def broken_constraints_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | BrokenConstraintsCount
                | o Property BrokenConstraintsCount() As long
                | 
                | Returns the number of broken constraints from the Constraints
                | collection.
                | Example:
                |   The following example retrieves in BknCstNum the
                |   number of broken constraints from the myListofConstraints collection
                |   of constraints:
                |       BknCstNum = myListofConstraints.BrokenConstraintsCount

        :return: int
        """
        return self.constraints.BrokenConstraintsCount

    @property
    def un_updated_constraints_count(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | UnUpdatedConstraintsCount
                | o Property UnUpdatedConstraintsCount() As long
                | 
                | Returns the number of unupdated constraints from the Constraints
                | collection.
                | Example:
                | The following example retrieves in UnUpdCstNum
                | the number of unupdated constraints from the myListofConstraints
                | collection of constraints:
                |   UnUpdCstNum = myListofConstraints.UnUpdatedConstraintsCount

        :return: int
        """
        return self.constraints.UnUpdatedConstraintsCount

    def add_bi_elt_cst(self, i_cst_type, i_first_elem, i_second_elem):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddBiEltCst
                | o Func AddBiEltCst(CatConstraintType iCstType,
                |                    Reference iFirstElem,
                |                    Reference iSecondElem) As Constraint
                | 
                | Creates a new constraint applying to two geometric elements and adds
                | it to the Constraints collection.
                |
                | Parameters:
                | iCstType
                |    The constraint type
                |  
                |  iFirstElem
                |    The first constrained geometric element
                |    The following 
                | 
                |  activateLinkAnchor('Boundary','','Boundary')  object is supported:    
                |  activateLinkAnchor('Boundary','','Boundary') . 
                |      iSecondElem
                |    The second constrained geometric element
                |    The following 
                |  activateLinkAnchor('Boundary','','Boundary')  object is supported:    
                |  activateLinkAnchor('Boundary','','Boundary') .
                |
                | Examples:
                | This example adds  the NewCst tangency constraint in a sketch,
                | between the two circles c1 and c2
                | using the value 4 for catCstTypeTangency.
                |   Set newCst = skCstList.AddBiEltCst(4, c1, c2)

        :param int i_cst_type:
        :param Reference() i_first_elem:
        :param Reference() i_second_elem:
        :return: Constraint()
        """
        return self.child_object(
            self.constraints.AddBiEltCst(i_cst_type, i_first_elem.com_object, i_second_elem.com_object))

    def add_mono_elt_cst(self, i_cst_type, i_elem):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddMonoEltCst
                | o Func AddMonoEltCst(    CatConstraintType    iCstType,
                |                          Reference    iElem) As Constraint
                | 
                | Creates a new constraint applying to a single geometric element and
                | adds it to the Constraints collection.
                |
                | Parameters:
                | iCstType
                |    The constraint type
                |  iElem
                |    The constrained geometric element
                |  The following
                |  activateLinkAnchor('Boundary','','Boundary')  object is supported:    
                |  activateLinkAnchor('Boundary','','Boundary') .
                |
                | Examples:
                | This example creates the reference constraint NewCst to a part,
                | stating that
                | the P1 point should remain fixed with respect to the part's
                | origin elements using the value 0 for catCstTypeReference,
                | and adds it to the cstList collection.
                |   Set NewCst = cstList.AddMonoEltCst(0, P1)

        :param int i_cst_type:
        :param Reference() i_elem:
        :return: Constraint()
        """
        return self.child_object(self.constraints.AddMonoEltCst(i_cst_type, i_elem.com_object))

    def add_tri_elt_cst(self, i_cst_type, i_first_elem, i_second_elem, i_third_elem):
        """
        .. note::
            CAA V5 Visual Basic help

                | AddTriEltCst
                | o Func AddTriEltCst(    CatConstraintType    iCstType,
                |                         Reference    iFirstElem,
                |                         Reference    iSecondElem,
                |                         Reference    iThirdElem) As Constraint
                | 
                | Creates a new constraint applying to three geometric elements and adds
                | it to the Constraints collection.


                | Parameters:
                | iCstType
                |    The constraint type
                |  
                |  iFirstElem
                |    The first constrained geometric element
                |    The following 
                | 
                |  activateLinkAnchor('Boundary','','Boundary')  object is supported:    
                |  activateLinkAnchor('Boundary','','Boundary') . 
                |      iSecondElem
                |    The second constrained geometric element
                |    The following 
                |  activateLinkAnchor('Boundary','','Boundary')  object is supported:    
                |  activateLinkAnchor('Boundary','','Boundary') . 
                |      iThirdElem
                |    The third constrained geometric element
                |    The following 
                |  activateLinkAnchor('Boundary','','Boundary')  object is supported:    
                |  activateLinkAnchor('Boundary','','Boundary') .


                | Examples:
                | 
                | 
                | This example adds symCst symmetry constraint in a part,
                | stating that the cylinders cyl1 and cyl2 are
                | symmetric with respect to the plane symPlane using the
                | value 15 for catCstTypeSymmetry.
                |   Set symCst = prtCstList.AddTriEltCst(15, cyl1, cyl2, symPlane)

        :param int i_cst_type:
        :param Reference() i_first_elem:
        :param Reference() i_second_elem:
        :param Reference() i_third_elem:
        :return: Constraint()
        """
        return self.child_object(
            self.constraints.AddTriEltCst(i_cst_type,
                                          i_first_elem.com_object,
                                          i_second_elem.com_object,
                                          i_third_elem.com_object)
        )

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(    CATVariant    iIndex) As Constraint
                | 
                | Returns a constraint using its index or its name from the Constraints
                | collection.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the constraint to retrieve frm
                |    the collection of constraints.
                |    As a numeric, this index is the rank of the constraint
                |    in the collection.
                |    The index of the first constraint in the collection is 1, and
                |    the index of the last constraint is Count.
                |    As a string, it is the name you assigned to the constraint using
                |    the 
                | 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property. 
                |    Returns:
                |   The retrieved constraint
                |
                | Examples:
                | This example retrieves in cst1 the first constraint
                | in the collection and in cst2 the constraint Constraint.2.
                |   Set cst1 = cstList.Item(1)
                |   Set cst2 = cstList.Item("Constraint.2")

        :return: Constraint()
        """
        return self.child_object(self.constraints.Item(i_index))

    def remove(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Remove
                | o Sub Remove(    CATVariant    iIndex)
                | 
                | Removes a constraint from the Constraints collection.
                |
                | Parameters:
                | iIndex
                |    The index or the name of the constraint to remove from the Constraints
                |    collection.
                |    As a numeric, this index is the rank of the constraint
                |    in the collection.
                |    The index of the first constraint in the collection is 1, and
                |    the index of the last constraint is Count.
                |    As a string, it is the name you assigned to the constraint using
                |    the 
                | 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property.


                | Examples:
                | This example removes the last constraint in the collection.
                |   cstList.Remove(cstList.Count)

        """
        return self.constraints.Remove(i_index)

    def __repr__(self):
        return f'Constraints(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-18 10:56:40.651039


from .face import Face


class CylindricalFace(Face):
    """
        .. note::
            CAA V5 Visual Basic help

                | 2-D boundary with a cylindrical geometry.Role:
                | ThisactivateLinkAnchor('Boundary','','Boundary')object may be, for
                | example, the lateral face of a cylinder. You will create a
                | CylindricalFace object using theactivateLinkAnchor('Shapes','GetBounda
                | ry','Shapes.GetBoundary'),activateLinkAnchor('HybridShapes','GetBounda
                | ry','HybridShapes.GetBoundary'),activateLinkAnchor('Sketches','GetBoun
                | dary','Sketches.GetBoundary')oractivateLinkAnchor('Selection','SelectE
                | lement2','Selection.SelectElement2')method. Then, you pass it to the
                | operator (such asactivateLinkAnchor('ShapeFactory','AddNewCircPattern'
                | ,'ShapeFactory.AddNewCircPattern')).  The lifetime of a
                | CylindricalFace object is limited,
                | seeactivateLinkAnchor('Boundary','','Boundary').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cylindrical_face = com_object

    def get_direction(self, o_direction):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetDirection
                | o Sub GetDirection(        oDirection)
                | 
                | Returns the direction of the cylindrical face axis
                |
                | Parameters:
                | oDirection[0]
                |    The X Coordinate of the axis direction 
                |    
                |  oDirection[1]
                |    The Y Coordinate of the axis direction
                |    
                |  oDirection[2]
                |    The Z Coordinate of the axis direction
                |

        :param o_direction:
        :return:
        """
        return self.cylindrical_face.GetDirection(o_direction)

    def get_origin(self, o_origin):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetOrigin
                | o Sub GetOrigin(        oOrigin)
                | 
                | Returns the origin of the cylindrical face axis.
                |
                | Parameters:
                | oOrigin[0]
                |    The X Coordinate of the axis origin
                |    
                |  oOrigin[1]
                |    The Y Coordinate of the axis origin
                |    
                |  oOrigin[2]
                |    The Z Coordinate of the axis origin
                |

        :param o_origin:
        :return:
        """
        return self.cylindrical_face.GetOrigin(o_origin)

    def __repr__(self):
        return f'CylindricalFace(name="{self.name}")'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA V5 R25

from pycatia.system_interfaces.collection import Collection
from .axis_system import AxisSystem


class AxisSystems(Collection):
    """
        .. note::
            CAA V5 Visual Basic help

                | A collection of all the AxisSystem objects contained in the part.

    """

    def __init__(self, collection_com_object):
        super().__init__(collection_com_object, child_object=AxisSystem)
        self.axis_systems = collection_com_object

    def add(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | Add
                | o Func Add() As AxisSystem
                | 
                | Creates a new AxisSystem and adds it to the AxisSystems collection.
                | Returns:  The created AxisSystem  Example: The following example
                | creates a AxisSystem names NewAxisSystem in the AxisSystem collection
                | of the rootPart part in the partDoc part document.  Set rootPart =
                | partDoc.Part Set NewAxisSystem = rootPart.AxisSystems.Add()


                | Parameters:


        """
        return self.child_object(self.axis_systems.Add())

    def item(self, i_index):
        """
        .. note::
            CAA V5 Visual Basic help

                | Item
                | o Func Item(    CATVariant    iIndex) As AxisSystem
                | 
                | Returns an Axis System using its index or its name from the
                | AxisSystems collection.


                | Parameters:
                | iIndex
                |    The index or the name of the AxisSystem to retrieve from
                |    the collection of AxisSystems.
                |    As a numeric, this index is the rank of the AxisSystem
                |    in the collection.
                |    The index of the first AxisSystem in the collection is 1, and
                |    the index of the last AxisSystem is Count.
                |    As a string, it is the name you assigned to the AxisSystem using
                |    the 
                | 
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property. 
                |    Returns:
                |   The retrieved AxisSystem


                | Examples:
                | 
                | 
                | This example retrieves in ThisAxisSystem the fifth AxisSystem
                | in the collection and in ThatAxisSystem the AxisSystem
                | named MyAxisSystem in the AxisSystem collection of the partDoc
                | part document.
                | 
                | Set AxisSystemColl = partDoc.Part.AxisSystems
                | Set ThisAxisSystem = AxisSystemColl.Item(5)
                | Set ThatAxisSystem = AxisSystemColl.Item("MyAxisSystem")

        """
        return self.child_object(self.axis_systems.Item(i_index))

    def __repr__(self):
        return f'AxisSystems()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-22 12:54:36.956119

from .face import Face


class PlanarFace(Face):
    """
        .. note::
            CAA V5 Visual Basic help

                | 2-D boundary with a planar geometry.Role:
                | ThisactivateLinkAnchor('Boundary','','Boundary')object may be, for
                | example, the face of a cube. You will create a PlanarFace object using
                | theactivateLinkAnchor('Shapes','GetBoundary','Shapes.GetBoundary'),act
                | ivateLinkAnchor('HybridShapes','GetBoundary','HybridShapes.GetBoundary
                | '),activateLinkAnchor('Sketches','GetBoundary','Sketches.GetBoundary')
                | oractivateLinkAnchor('Selection','SelectElement2','Selection.SelectEle
                | ment2')method. Then, you pass it to the operator (such asactivateLinkA
                | nchor('ShapeFactory','AddNewDraft','ShapeFactory.AddNewDraft')).  The
                | lifetime of a PlanarFace object is limited,
                | seeactivateLinkAnchor('Boundary','','Boundary').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.planar_face = com_object

    def get_first_axis(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetFirstAxis
                | o Sub GetFirstAxis(        oFirstAxis)
                | 
                | Returns the planar face first axis
                |
                | Parameters:
                | oFirstAxis[0]
                |    The X Coordinate of the planar face first axis
                |    
                |  oFirstAxis[1]
                |    The Y Coordinate of the planar face first axis
                |    
                |  oFirstAxis[2]
                |    The Z Coordinate of the planar face first axis


        :return:
        """
        return self.planar_face.GetFirstAxis()

    def get_origin(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetOrigin
                | o Sub GetOrigin(        oOrigin)
                | 
                | Returns the origin of the planar face.
                |
                | Parameters:
                | oOrigin[0]
                |    The X Coordinate of the planar face origin
                |    
                |  oOrigin[1]
                |    The Y Coordinate of the planar face origin
                |    
                |  oOrigin[2]
                |    The Z Coordinate of the planar face origin


        :return:
        """
        return self.planar_face.GetOrigin()

    def get_second_axis(self):
        """
        .. note::
            CAA V5 Visual Basic help

                | GetSecondAxis
                | o Sub GetSecondAxis(        oSecondAxis)
                | 
                | Returns the planar face second axis.
                |
                | Parameters:
                | oSecondAxis[0]
                |     The X Coordinate of the planar face second axis
                |    
                |  oSecondAxis[1]
                |    The Y Coordinate of the planar face second axis
                |    
                |  oSecondAxis[2]
                |    The Z Coordinate of the planar face second axis


        :return:
        """
        return self.planar_face.GetSecondAxis()

    def __repr__(self):
        return f'PlanarFace(name="{self.name}")'



#! /usr/bin/python3.6

from pycatia.cat_logger import create_logger


class PyCATIA:

    def __init__(self):
        pass

    @property
    def logger(self):
        return create_logger(self)

    def __repr__(self):
        return 'PyCATIA()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-18 10:56:40.651039


from .boundary import Boundary


class Edge(Boundary):
    """
        .. note::
            CAA V5 Visual Basic help

                | 1-D boundary.Role:
                | ThisactivateLinkAnchor('Boundary','','Boundary')object may be, for
                | example, the edge of a cylinder. You will create an Edge object using 
                | theactivateLinkAnchor('Shapes','GetBoundary','Shapes.GetBoundary'),act
                | ivateLinkAnchor('HybridShapes','GetBoundary','HybridShapes.GetBoundary
                | '),activateLinkAnchor('Sketches','GetBoundary','Sketches.GetBoundary')
                | oractivateLinkAnchor('Selection','SelectElement2','Selection.SelectEle
                | ment2')method. Then, you pass it to the operator (such asactivateLinkA
                | nchor('HybridShapeFactory','AddNewPointTangent','HybridShapeFactory.Ad
                | dNewPointTangent')).  The lifetime of an Edge object is limited,
                | seeactivateLinkAnchor('Boundary','','Boundary').See also:activateLinkA
                | nchor('TriDimFeatEdge','','TriDimFeatEdge'),activateLinkAnchor('Rectil
                | inearTriDimFeatEdge','','RectilinearTriDimFeatEdge'),activateLinkAncho
                | r('BiDimFeatEdge','','BiDimFeatEdge'),activateLinkAnchor('RectilinearB
                | iDimFeatEdge','','RectilinearBiDimFeatEdge'),activateLinkAnchor('MonoD
                | imFeatEdge','','MonoDimFeatEdge'),activateLinkAnchor('RectilinearMonoD
                | imFeatEdge','','RectilinearMonoDimFeatEdge').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.edge = com_object

    def __repr__(self):
        return f'Edge()'



#! /usr/bin/python3.6
# module initially auto generated using V5Automation.chm from CATIA R25 on 2020-05-22 12:54:36.956119

from .boundary import Boundary


class Vertex(Boundary):
    """
        .. note::
            CAA V5 Visual Basic help

                | 0-D boundary.Role:
                | ThisactivateLinkAnchor('Boundary','','Boundary')object may be, for
                | example, the corner of a Pad resulting from the extrusion of a
                | square. You will create an Vertex object using theactivateLinkAnchor('
                | Shapes','GetBoundary','Shapes.GetBoundary'),activateLinkAnchor('Hybrid
                | Shapes','GetBoundary','HybridShapes.GetBoundary'),activateLinkAnchor('
                | Sketches','GetBoundary','Sketches.GetBoundary')oractivateLinkAnchor('S
                | election','SelectElement2','Selection.SelectElement2')method. Then,
                | you pass it to the operator (such asactivateLinkAnchor('HybridShapeFac
                | tory','AddNewLinePtPt','HybridShapeFactory.AddNewLinePtPt')).  The
                | lifetime of a Vertex object is limited,
                | seeactivateLinkAnchor('Boundary','','Boundary').See also:activateLinkA
                | nchor('TriDimFeatVertexOrBiDimFeatVertex','','TriDimFeatVertexOrBiDimF
                | eatVertex'),activateLinkAnchor('NotWireBoundaryMonoDimFeatVertex','','
                | NotWireBoundaryMonoDimFeatVertex'),activateLinkAnchor('ZeroDimFeatVert
                | exOrWireBoundaryMonoDimFeatVertex','','ZeroDimFeatVertexOrWireBoundary
                | MonoDimFeatVertex').

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.vertex = com_object

    def __repr__(self):
        return f'Vertex(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.part_interfaces.defeaturing_filter import DefeaturingFilter
from pycatia.system_interfaces.collection import Collection


class DefeaturingFilters(Collection):
    """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DefeaturingFilters
                | 
                | Represents the filter collection of a defeaturing object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.defeaturing_filters = com_object

    def add(self, i_filter_type_to_add):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(CATBSTR iFilterTypeToAdd) As long
                | 
                |     Creates a new filter and adds it to the Defeaturing filters
                |     collection.
                | 
                |     Parameters:
                | 
                |         iFilterTypeToAdd
                |             The type of the new filter to add among : - "DefeaturingFilletFilter" -
                |             "DefeaturingHoleFilter" - or any user-defined filter's type
                | 
                |     Returns:
                |         oAddedFilterIndex The added filter's index - equals to 0 if
                |         FAILED
                | 
                |         Example:
                |             The following example adds a new filter of type theFilterType to
                |             defeaturing colelction firstDefeaturingFilters and returns the index theIndex
                |             of the new filter
                | 
                |              Set theIndex = firstDefeaturingFilters.Add(theFilterType)

        :param str i_filter_type_to_add:
        :return: int
        """
        return self.defeaturing_filters.Add(i_filter_type_to_add)

    def item(self, i_filter_id):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iFilterId) As DefeaturingFilter
                | 
                |     Returns the filter of the Defeaturing filters collection using its index or
                |     its name.
                | 
                |     Parameters:
                | 
                |         iFilterId
                |             The index or the name of the filter to retrieve As a numerics, must
                |             be in [1;Count]) 
                | 
                |     Returns:
                |         oFilter The filter (see DefeaturingFilter for list of possible
                |         actions)
                | 
                |         Example:
                |             The following example returns in myFilter the filter number
                |             theIndex of Defeaturing collection
                |             firstDefeaturingFilters:
                | 
                |              Set myFilter = firstDefeaturingFilters.Item(theIndex)

        :param CATVariant i_filter_id:
        :return: DefeaturingFilter
        """
        return DefeaturingFilter(self.defeaturing_filters.Item(i_filter_id.com_object))

    def remove(self, i_filter_id):
        """
        .. note::
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iFilterId)
                | 
                |     Removes a filter from the Defeaturing filters collection and deletes it,
                |     using its index or its name.
                | 
                |     Parameters:
                | 
                |         iFilterId
                |             The index or the name of the filter to retrieve As a numerics, must
                |             be in [1;Count])
                | 
                |             Example:
                |                 The two following examples remove the filter number theIndex
                |                 from Defeaturing collection
                |                 firstDefeaturingFilters:
                | 
                |                  Call firstDefeaturingFilters.Remove(theIndex)
                |                  firstDefeaturingFilters.Remove theIndex

        :param CATVariant i_filter_id:
        :return: None
        """
        return self.defeaturing_filters.Remove(i_filter_id.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(defeaturing_filters)
        # #     Dim iFilterId (2)
        # #     defeaturing_filters.Remove iFilterId
        # #     remove = iFilterId
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DefeaturingFilters(name="{self.name}")'
